@@ -13,9 +13,8 @@
 ##############################################################################
 """Catalog Views
 
-$Id: catalog.py 27347 2004-08-29 21:10:45Z jim $
+$Id: catalog.py 30583 2005-05-31 22:05:18Z jim $
 """
-from zope.app.container.browser.adding import Adding
 from zope.app.catalog.interfaces import ICatalog
 
 class Advanced:
@@ -30,4 +29,4 @@ class Advanced:
     def reindex(self):
         self.context.clear()
         self.context.updateIndexes()
-        self.request.response.redirect(".")
+        self.request.response.redirect('@@advanced.html')
