@@ -13,13 +13,13 @@
 ##############################################################################
 """Basic File interfaces.
 
-$Id: interfaces.py 37641 2005-08-01 21:15:22Z srichter $
+$Id: interfaces.py 39064 2005-10-11 18:40:10Z philikon $
 """
 __docformat__ = 'restructuredtext'
 
 from zope.schema import BytesLine, Bytes
 from zope.interface import Interface
-from zope.app.i18n import ZopeMessageIDFactory as _
+from zope.app.i18n import ZopeMessageFactory as _
 
 
 # BBB: To go away in 3.3
