@@ -13,17 +13,16 @@
 ##############################################################################
 """Folder interfaces
 
-$Id: interfaces.py 27515 2004-09-13 19:21:00Z fdrake $
+$Id: interfaces.py 30851 2005-06-18 17:02:06Z anguenot $
 """
 __docformat__ = 'restructuredtext'
 
-from zope.app.container.interfaces import IContainer, IContentContainer
+from zope.app.container.interfaces import IContainer
 from zope.app.traversing.interfaces import IContainmentRoot
-from zope.app.site.interfaces import IPossibleSite
+from zope.app.component.interfaces import IPossibleSite
 from zope.app.annotation.interfaces import IAttributeAnnotatable
 
-class IFolder(IContainer, IContentContainer, IPossibleSite,
-              IAttributeAnnotatable):
+class IFolder(IContainer, IPossibleSite, IAttributeAnnotatable):
     """The standard Zope Folder object interface."""
 
 class IRootFolder(IFolder, IContainmentRoot):
