@@ -13,7 +13,7 @@
 ##############################################################################
 """Browser widgets for sequences
 
-$Id: sequencewidget.py 37427 2005-07-26 14:02:02Z hdima $
+$Id: sequencewidget.py 39064 2005-10-11 18:40:10Z philikon $
 """
 __docformat__ = 'restructuredtext'
 
@@ -26,7 +26,7 @@ from zope.app.form.interfaces import WidgetInputError, MissingInputError
 from zope.app.form import InputWidget
 from zope.app.form.browser.widget import BrowserWidget
 from zope.app.form.browser.widget import DisplayWidget, renderElement
-from zope.app.i18n import ZopeMessageIDFactory as _
+from zope.app.i18n import ZopeMessageFactory as _
 
 class SequenceWidget(BrowserWidget, InputWidget):
     """A widget baseclass for a sequence of fields.
