@@ -13,12 +13,13 @@
 ##############################################################################
 """Select Widget Tests
 
-$Id: test_itemswidget.py 28147 2004-10-14 07:56:27Z srichter $
+$Id: test_itemswidget.py 37976 2005-08-17 00:38:32Z poster $
 """
+import sets
 import unittest
 
 from zope.interface import Interface, implements
-from zope.schema import Choice, List
+from zope.schema import Choice, List, Set, TextLine
 from zope.schema.vocabulary import SimpleVocabulary, SimpleTerm
 from zope.publisher.browser import TestRequest
 
@@ -36,7 +37,7 @@ from zope.app.form.browser.itemswidgets import MultiSelectWidget
 from zope.app.form.browser.itemswidgets import OrderedMultiSelectWidget
 from zope.app.form.browser.itemswidgets import MultiCheckBoxWidget
 from zope.app.form.browser.tests.support import VerifyResults
-from zope.app.tests.placelesssetup import PlacelessSetup 
+from zope.app.testing.placelesssetup import PlacelessSetup 
 
 vocab = SimpleVocabulary(
     [SimpleTerm(value, token, title) for value, token, title in (
@@ -58,6 +59,12 @@ class ICollector(Interface):
         value_type=choice,
         required=False)
 
+    letters = Set(
+        title=u"Letters",
+        description=u"The Letters",
+        value_type=choice,
+        required=False)
+
 
 class Collector(object):
     implements(ICollector)
@@ -114,6 +121,8 @@ class ItemDisplayWidgetTest(ItemsWidgetBaseTest):
         widget = self._makeWidget(form={'field.choice': 'token1'})
         self.assertEqual(widget(), 'One')
 
+    def test_not_required(self):
+        self.failIf(self._makeWidget().required)
 
 class ItemsMultiDisplayWidgetTest(ItemsWidgetBaseTest):
     
@@ -144,6 +153,15 @@ class ItemsMultiDisplayWidgetTest(ItemsWidgetBaseTest):
         self.assertRaises(TypeError, widget.renderItems, 1)
 
 
+    def test_not_required(self):
+        numbers = List(value_type=ICollector['choice']).bind(Collector(None))
+        request = TestRequest()
+        widget = self._widget(numbers, self._vocabulary, request) 
+        self.failIf(widget.required)
+
+
+        
+
 class ListDisplayWidgetTest(ItemsMultiDisplayWidgetTest):
     _widget = ListDisplayWidget
     _tag = 'ol'
@@ -198,11 +216,13 @@ class ItemsEditWidgetBaseTest(ItemsWidgetBaseTest):
              u'<option value="token2">Two</option>',
              u'<option value="token3">Three</option>'])             
 
-    def test_error(self):
-        widget = self._makeWidget(form={'field.choice': 'ten'})
-        widget.setPrefix('field.')
-        widget._getFormValue()
-        self.assert_(isinstance(widget._error, ConversionError))
+# This test is disabled because it tests for the presense of a missfeature,
+# which has been removed.  Did someone actually *want* this?
+##     def test_error(self):
+##         widget = self._makeWidget(form={'field.choice': 'ten'})
+##         widget.setPrefix('field.')
+##         widget._getFormValue()
+##         self.assert_(isinstance(widget._error, ConversionError))
     
     def test_hidden(self):
         widget = self._makeWidget(form={'field.choice': 'token2'})
@@ -224,9 +244,9 @@ class SelectWidgetTest(ItemsEditWidgetBaseTest):
         widget.context.required = False
         self.assertEqual(
             widget(),
-            '<div id="field.choice">\n'
+            '<div>\n'
             '<div class="value">\n'
-            '<select name="field.choice" size="%i" >\n'
+            '<select id="field.choice" name="field.choice" size="%i" >\n'
             '<option value="">(no value)</option>\n'
             '<option selected="selected" value="token1">One</option>\n'
             '<option value="token2">Two</option>\n'
@@ -240,7 +260,7 @@ class SelectWidgetTest(ItemsEditWidgetBaseTest):
         widget.setPrefix('field.')
         self.assertEqual(
             widget.renderValue('one'),
-            '<select name="field.choice" size="%i" >\n'
+            '<select id="field.choice" name="field.choice" size="%i" >\n'
             '<option selected="selected" value="token1">One</option>\n'
             '<option value="token2">Two</option>\n'
             '<option value="token3">Three</option>\n'
@@ -395,11 +415,13 @@ class ItemsMultiEditWidgetBaseTest(ItemsEditWidgetBaseTest):
              '>One</option>\n', 'value="token2"', '>Two</option>\n',
              'value="token3"', '>Three</option>', '</select>'])
 
-    def test_error(self):
-        widget = self._makeWidget(form={'field.numbers': ['ten']})
-        widget.setPrefix('field.')
-        widget._getFormValue()
-        self.assert_(isinstance(widget._error, ConversionError))
+# This test is disabled because it tests for the presense of a missfeature,
+# which has been removed.  Did someone actually *want* this?
+##     def test_error(self):
+##         widget = self._makeWidget(form={'field.numbers': ['ten']})
+##         widget.setPrefix('field.')
+##         widget._getFormValue()
+##         self.assert_(isinstance(widget._error, ConversionError))
     
     def test_hidden(self):
         widget = self._makeWidget(
@@ -411,6 +433,18 @@ class ItemsMultiEditWidgetBaseTest(ItemsEditWidgetBaseTest):
             ['<input', 'type="hidden"', 'value="token2"', 'id="field.numbers"', 
              'name="field.numbers:list"', 'value="token3"'])
 
+    def test_getInputValue(self):
+        widget = self._makeWidget(form={'field.numbers': ['token2','token3']})
+        widget.setPrefix('field.')
+        self.assertEqual(widget.getInputValue(), ['two', 'three'])
+
+        self._field = ICollector.get('letters')
+        widget = self._makeWidget(form={'field.letters': ['token2','token3']})
+        widget.setPrefix('field.')
+        self.assertEqual(widget.getInputValue(), sets.Set(['two', 'three']))
+        self._field = ICollector.get('numbers')
+
+
 
 class MultiSelectWidgetTest(ItemsMultiEditWidgetBaseTest):
 
@@ -429,6 +463,11 @@ class OrderedMultiSelectWidgetTest(ItemsMultiEditWidgetBaseTest):
 
     def test_selected(self):
         widget = self._makeWidget(nums=['one'])
+        widget._data = ['two']
+        selected = [select['text'] for select in widget.selected()]
+        selected.sort()
+        self.assertEqual(selected, ['One', 'Two'])
+        widget._data = ['one']
         selected = [select['text'] for select in widget.selected()]
         selected.sort()
         self.assertEqual(selected, ['One'])
