@@ -13,23 +13,24 @@
 ##############################################################################
 """Filesystem synchronization functions.
 
-$Id: syncer.py 26749 2004-07-24 06:10:42Z pruggera $
+$Id: syncer.py 29143 2005-02-14 22:43:16Z srichter $
 """
 __docformat__ = 'restructuredtext'
 
-from zope.component import getService
+from zope.app import zapi
 from zope.fssync.server.syncer import Syncer
 
 from zope.app.annotation.interfaces import IAnnotations
 from zope.app.traversing.api import getPath
 
+from interfaces import IGlobalFSSyncUtility
 
 def getObjectId(obj):
     return str(getPath(obj))
 
 def getSerializer(obj):
-    syncService = getService('FSRegistryService')
-    return syncService.getSynchronizer(obj)
+    syncUtility = zapi.getUtility(IGlobalFSSyncUtility)
+    return syncUtility.getSynchronizer(obj)
 
 def getAnnotations(obj):
     return IAnnotations(obj, None)
