@@ -13,16 +13,15 @@
 ##############################################################################
 """Tests for the Committer class.
 
-$Id: test_committer.py 28263 2004-10-26 22:59:30Z jim $
+$Id: test_committer.py 37557 2005-07-29 18:19:31Z benji_york $
 """
-
 import os
 import shutil
 import tempfile
 import unittest
 
-from zope.component.service import serviceManager
-from zope.app.tests import ztapi
+from zope.app import zapi
+from zope.app.testing import ztapi
 from zope.app.traversing.interfaces import TraversalError
 from zope.interface import implements
 
@@ -39,12 +38,12 @@ from zope.app.filerepresentation.interfaces import IDirectoryFactory
 from zope.app.traversing.interfaces import IContainmentRoot
 from zope.app.traversing.interfaces import ITraversable, ITraverser
 from zope.app.location import Location
-from zope.app.tests.placelesssetup import PlacelessSetup
+from zope.app.testing.placelesssetup import PlacelessSetup
 
 from zope.app.fssync import committer, syncer # The module
 from zope.app.fssync.committer import Checker, Committer, SynchronizationError
 from zope.app.fssync.fsregistry import provideSynchronizer, fsRegistry
-from zope.app.fssync.interfaces import IGlobalFSSyncService
+from zope.app.fssync.interfaces import IGlobalFSSyncUtility
 
 
 class Sample(object):
@@ -120,12 +119,11 @@ class TestBase(PlacelessSetup, TempFiles):
     # Base class for test classes
 
     def setUp(self):
-        # Set up standard services
         super(TestBase, self).setUp()
 
-        # Set up FSRegistryService
-        serviceManager.defineService("FSRegistryService", IGlobalFSSyncService)
-        serviceManager.provideService("FSRegistryService", fsRegistry)
+        # Set up FSRegistryUtility
+        gsm = zapi.getGlobalSiteManager()
+        gsm.provideUtility(IGlobalFSSyncUtility, fsRegistry)
         provideSynchronizer(None, DefaultFileAdpater)
 
         # Set up temporary name administration
@@ -135,7 +133,6 @@ class TestBase(PlacelessSetup, TempFiles):
         # Clean up temporary files and directories
         TempFiles.tearDown(self)
 
-        # Clean up service registrations etc.
         PlacelessSetup.tearDown(self)
 
 
@@ -536,9 +533,9 @@ class TestCheckerClass(TestBase):
         self.fooentry.clear()
         self.check_no_errors()
 
-    # XXX Extra and Annotations is not tested directly
+    # TODO Extra and Annotations is not tested directly
 
-    # XXX Changing directories into files or vice versa is not tested
+    # TODO Changing directories into files or vice versa is not tested
 
 
 
