@@ -13,7 +13,7 @@
 ##############################################################################
 """Test HTTP PUT verb
 
-$Id: test_put.py 29143 2005-02-14 22:43:16Z srichter $
+$Id: test_put.py 39612 2005-10-25 13:47:23Z mkerrin $
 """
 from unittest import TestCase, TestSuite, makeSuite
 from StringIO import StringIO
@@ -52,7 +52,7 @@ class TestNullPUT(PlacelessSetup, TestCase):
     def test(self):
         container = Container()
         content = "some content\n for testing"
-        request = TestRequest(StringIO(content), StringIO(),
+        request = TestRequest(StringIO(content),
                               {'CONTENT_TYPE': 'test/foo',
                                'CONTENT_LENGTH': str(len(content)),
                                })
@@ -60,7 +60,7 @@ class TestNullPUT(PlacelessSetup, TestCase):
         put = zope.app.http.put.NullPUT(null, request)
         self.assertEqual(getattr(container, 'spam', None), None)
         self.assertEqual(put.PUT(), '')
-        request.response.setBody('')
+        request.response.setResult('')
         file = container.spam
         self.assertEqual(file.__class__, File)
         self.assertEqual(file.name, 'spam')
@@ -71,9 +71,13 @@ class TestNullPUT(PlacelessSetup, TestCase):
         self.assertEqual(request.response.getStatus(), 201)
 
     def test_bad_content_header(self):
+        ## The previous behavour of the PUT method was to fail if the request
+        ## object had a key beginning with 'HTTP_CONTENT_' with a status of 501.
+        ## This was breaking the new Twisted server, so I am now allowing this
+        ## this type of request to be valid.
         container = Container()
         content = "some content\n for testing"
-        request = TestRequest(StringIO(content), StringIO(),
+        request = TestRequest(StringIO(content),
                               {'CONTENT_TYPE': 'test/foo',
                                'CONTENT_LENGTH': str(len(content)),
                                'HTTP_CONTENT_FOO': 'Bar',
@@ -82,40 +86,44 @@ class TestNullPUT(PlacelessSetup, TestCase):
         put = zope.app.http.put.NullPUT(null, request)
         self.assertEqual(getattr(container, 'spam', None), None)
         self.assertEqual(put.PUT(), '')
-        request.response.setBody('')
+        request.response.setResult('')
 
         # Check HTTP Response
-        self.assertEqual(request.response.getStatus(), 501)
+        self.assertEqual(request.response.getStatus(), 201)
 
 class TestFilePUT(PlacelessSetup, TestCase):
 
     def test(self):
         file = File("thefile", "text/x", "initial content")
         content = "some content\n for testing"
-        request = TestRequest(StringIO(content), StringIO(),
+        request = TestRequest(StringIO(content),
                               {'CONTENT_TYPE': 'test/foo',
                                'CONTENT_LENGTH': str(len(content)),
                                })
         put = zope.app.http.put.FilePUT(file, request)
         self.assertEqual(put.PUT(), '')
-        request.response.setBody('')
+        request.response.setResult('')
         self.assertEqual(file.data, content)
 
     def test_bad_content_header(self):
+        ## The previous behavour of the PUT method was to fail if the request
+        ## object had a key beginning with 'HTTP_CONTENT_' with a status of 501.
+        ## This was breaking the new Twisted server, so I am now allowing this
+        ## this type of request to be valid.
         file = File("thefile", "text/x", "initial content")
         content = "some content\n for testing"
-        request = TestRequest(StringIO(content), StringIO(),
+        request = TestRequest(StringIO(content),
                               {'CONTENT_TYPE': 'test/foo',
                                'CONTENT_LENGTH': str(len(content)),
                                'HTTP_CONTENT_FOO': 'Bar',
                                })
         put = zope.app.http.put.FilePUT(file, request)
         self.assertEqual(put.PUT(), '')
-        request.response.setBody('')
-        self.assertEqual(file.data, "initial content")
+        request.response.setResult('')
+        self.assertEqual(file.data, content)
 
         # Check HTTP Response
-        self.assertEqual(request.response.getStatus(), 501)
+        self.assertEqual(request.response.getStatus(), 200)
 
 def test_suite():
     return TestSuite((
