@@ -13,9 +13,6 @@
 ##############################################################################
 """Presentation-component support
 
-$Id: __init__.py 27569 2004-09-17 16:15:36Z srichter $
+$Id: __init__.py 29143 2005-02-14 22:43:16Z srichter $
 """
 __docformat__ = 'restructuredtext'
-
-from zope.app.presentation.presentation import IPageRegistration
-from zope.app.presentation.presentation import PageRegistration
