@@ -13,24 +13,17 @@
 ##############################################################################
 """Content Component Definition and Instance
 
-$Id: content.py 29143 2005-02-14 22:43:16Z srichter $
+$Id: content.py 38178 2005-08-30 21:50:19Z mj $
 """
 from persistent import Persistent
 from persistent.dict import PersistentDict
-from zope.app import zapi
-from zope.app.i18n import ZopeMessageIDFactory as _
-from zope.app.annotation.interfaces import IAnnotations
-from zope.app.container.interfaces import IAdding
-from zope.app.component.interfaces.registration import ActiveStatus
 from zope.app.container.contained import Contained
 from zope.app.component.site import UtilityRegistration
-from zope.component.exceptions import ComponentLookupError
 from zope.interface import directlyProvides, implements
 from zope.schema import getFields
 from zope.security.checker import CheckerPublic, Checker, defineChecker
-from zope.security.proxy import removeSecurityProxy
 
-from interfaces import IContentComponentDefinition 
+from interfaces import IContentComponentDefinition
 from interfaces import IContentComponentInstance
 
 
@@ -101,7 +94,7 @@ class ContentComponentInstance(Persistent):
         if is_schema_field:
             super(ContentComponentInstance, self).__setattr__(key, value)
         else:
-            raise AttributeError, 'Attribute "%s" not available' %key
+            raise AttributeError('Attribute "%s" not available' % key)
 
 
     def getSchema(self):
