@@ -13,7 +13,7 @@
 ##############################################################################
 """Security Tests
 
-$Id: __init__.py 26567 2004-07-16 06:58:27Z srichter $
+$Id: __init__.py 29143 2005-02-14 22:43:16Z srichter $
 """
 from zope.app import zapi
 from zope.app.security.permission import Permission
@@ -22,8 +22,6 @@ from zope.app.security.interfaces import IPermission
 def addCheckerPublic():
     """Add the CheckerPublic permission as 'zope.Public'"""
 
-    utilityService = zapi.getGlobalService(zapi.servicenames.Utilities)
-
     perm = Permission('zope.Public', 'Public',
             """Special permission used for resources that are always public
 
@@ -31,4 +29,5 @@ def addCheckerPublic():
             it allows security computation to be bypassed.
             """
             )
-    utilityService.provideUtility(IPermission, perm, perm.id)
+    gsm = zapi.getGlobalSiteManager()
+    gsm.provideUtility(IPermission, perm, perm.id)
