@@ -13,7 +13,7 @@
 ##############################################################################
 """Absolute URL View components
 
-$Id: absoluteurl.py 30886 2005-06-22 13:48:35Z hdima $
+$Id: absoluteurl.py 39064 2005-10-11 18:40:10Z philikon $
 """
 import urllib
 from zope.interface import implements
@@ -21,7 +21,7 @@ from zope.proxy import sameProxiedObjects
 from zope.publisher.browser import IBrowserRequest
 
 import zope.component
-from zope.app.i18n import ZopeMessageIDFactory as _
+from zope.app.i18n import ZopeMessageFactory as _
 from zope.app.publisher.browser import BrowserView
 from zope.app.traversing.browser.interfaces import IAbsoluteURL
 
@@ -53,13 +53,13 @@ class AbsoluteURL(BrowserView):
 
         container = getattr(context, '__parent__', None)
         if container is None:
-            raise TypeError, _insufficientContext
+            raise TypeError(_insufficientContext)
 
         url = str(zope.component.getMultiAdapter((container, request),
                                                  name='absolute_url'))
         name = self._getContextName(context)
         if name is None:
-            raise TypeError, _insufficientContext
+            raise TypeError(_insufficientContext)
 
         if name:
             url += '/' + urllib.quote(name.encode('utf-8'), _safe)
@@ -78,7 +78,7 @@ class AbsoluteURL(BrowserView):
         # We do this here do maintain the rule that we must be wrapped
         container = getattr(context, '__parent__', None)
         if container is None:
-            raise TypeError, _insufficientContext
+            raise TypeError(_insufficientContext)
 
         if sameProxiedObjects(context, request.getVirtualHostRoot()) or \
                isinstance(context, Exception):
@@ -89,7 +89,7 @@ class AbsoluteURL(BrowserView):
 
         name = getattr(context, '__name__', None)
         if name is None:
-            raise TypeError, _insufficientContext
+            raise TypeError(_insufficientContext)
 
         if name:
             base += ({'name': name,
