@@ -13,7 +13,7 @@
 ##############################################################################
 """Functional Tests for StatefulProcessDefinition
 
-$Id: test_processdefinition.py 38053 2005-08-23 21:45:13Z fdrake $
+$Id: test_processdefinition.py 40178 2005-11-16 21:16:51Z srichter $
 """
 import unittest
 import re
@@ -137,7 +137,7 @@ class Test(BrowserTestCase):
 
         self.assert_(body.find('initial_foo') >= 0)
 
-        self.assert_(body.find('Import was successful!') >= 0)
+        self.assert_(body.find('Import was successfull!') >= 0)
 
 
 def test_suite():
