@@ -22,12 +22,14 @@ There are three flavors of declarations:
 
   - ProvidesDeclarations are used to express interfaces directly
     provided by objects.
-    
 
-$Id: declarations.py 28959 2005-01-26 16:49:06Z frerich $
+
+$Id: declarations.py 40184 2005-11-16 22:42:26Z srichter $
 """
 __docformat__ = 'restructuredtext'
+
 import sys
+import types
 import weakref
 from zope.interface.interface import InterfaceClass, Specification
 from ro import mergeOrderings, ro
@@ -35,13 +37,11 @@ import exceptions
 from types import ClassType
 from zope.interface.advice import addClassAdvisor
 
-# Registry of class-implementation specifications 
+# Registry of class-implementation specifications
 BuiltinImplementationSpecifications = {}
 
 class Declaration(Specification):
-    """Interface declarations
-
-    """
+    """Interface declarations"""
 
     def __init__(self, *interfaces):
         Specification.__init__(self, _normalizeargs(interfaces))
@@ -56,7 +56,7 @@ class Declaration(Specification):
     def __contains__(self, interface):
         """Test whether an interface is in the specification
 
-        for example::
+        for example:
 
           >>> from zope.interface import Interface
           >>> class I1(Interface): pass
@@ -83,7 +83,7 @@ class Declaration(Specification):
     def __iter__(self):
         """Return an iterator for the interfaces in the specification
 
-        for example::
+        for example:
 
           >>> from zope.interface import Interface
           >>> class I1(Interface): pass
@@ -111,7 +111,7 @@ class Declaration(Specification):
     def flattened(self):
         """Return an iterator of all included and extended interfaces
 
-        for example::
+        for example:
 
           >>> from zope.interface import Interface
           >>> class I1(Interface): pass
@@ -144,7 +144,7 @@ class Declaration(Specification):
     def __sub__(self, other):
         """Remove interfaces from a specification
 
-        Examples::
+        Examples:
 
           >>> from zope.interface import Interface
           >>> class I1(Interface): pass
@@ -183,12 +183,11 @@ class Declaration(Specification):
                         if i.extends(j, 0)]
                 ]
                 )
-    
+
     def __add__(self, other):
         """Add two specifications or a specification and an interface
 
-
-        Examples::
+        Examples:
 
           >>> from zope.interface import Interface
           >>> class I1(Interface): pass
@@ -260,14 +259,18 @@ class Declaration(Specification):
 # These specify interfaces implemented by instances of classes
 
 class Implements(Declaration):
+
+    # class whose specification should be used as additional base
     inherit = None
+
+    # interfaces actually declared for a class
     declared = ()
+
     __name__ = '?'
 
     def __repr__(self):
         return '<implementedBy %s>' % (self.__name__)
-    
-        
+
 
 def implementedByFallback(cls):
     """Return the interfaces implemented for a class' instances
@@ -291,19 +294,31 @@ def implementedByFallback(cls):
         ...   implements(I3)
         >>> [i.getName() for i in implementedBy(C2)]
         ['I3', 'I2']
-      """
 
+      Really, any object should be able to receive a successful answer, even
+      an instance:
+
+        >>> class Callable(object):
+        ...     def __call__(self):
+        ...         return self
+
+        >>> implementedBy(Callable())
+        <implementedBy zope.interface.declarations.?>
+
+      Note that the name of the spec ends with a '?', because the `Callable`
+      instance does not have a `__name__` attribute.
+      """
     # This also manages storage of implementation specifications
 
     try:
         spec = cls.__dict__.get('__implemented__')
     except AttributeError:
-        
+
         # we can't get the class dict. This is probably due to a
         # security proxy.  If this is the case, then probably no
         # descriptor was installed for the class.
 
-        # We don't want to depend directly on zope.secury in
+        # We don't want to depend directly on zope.security in
         # zope.interface, but we'll try to make reasonable
         # accommodations in an indirect way.
 
@@ -316,7 +331,7 @@ def implementedByFallback(cls):
             if spec is not None:
                 return spec
             return _empty
-        
+
         if spec.__class__ == Implements:
             # we defaulted to _empty or there was a spec. Good enough.
             # Return it.
@@ -326,7 +341,7 @@ def implementedByFallback(cls):
         # Hm, there's an __implemented__, but it's not a spec. Must be
         # an old-style declaration. Just compute a spec for it
         return Declaration(*_normalizeargs((spec, )))
-        
+
     if isinstance(spec, Implements):
         return spec
 
@@ -335,7 +350,7 @@ def implementedByFallback(cls):
         if spec is not None:
             return spec
 
-    # TODO: need old style __implements__ comptability?
+    # TODO: need old style __implements__ compatibility?
     if spec is not None:
         # old-style __implemented__ = foo declaration
         spec = (spec, ) # tuplefy, as it might be just an int
@@ -346,12 +361,15 @@ def implementedByFallback(cls):
         try:
             bases = cls.__bases__
         except AttributeError:
-            raise TypeError("ImplementedBy called for non-type", cls)
+            if not callable(cls):
+                raise TypeError("ImplementedBy called for non-factory", cls)
+            bases = ()
 
         spec = Implements(*[implementedBy(c) for c in bases])
         spec.inherit = cls
 
-    spec.__name__ = getattr(cls, '__module__', '?') + '.' + cls.__name__
+    spec.__name__ = (getattr(cls, '__module__', '?') or '?') + \
+                    '.' + (getattr(cls, '__name__', '?') or '?')
 
     try:
         cls.__implemented__ = spec
@@ -366,7 +384,7 @@ def implementedByFallback(cls):
                 cls,
                 getattr(cls, '__class__', type(cls)),
                 )
-                        
+
     except TypeError:
         if not isinstance(cls, type):
             raise TypeError("ImplementedBy called for non-type", cls)
@@ -379,83 +397,78 @@ implementedBy = implementedByFallback
 def classImplementsOnly(cls, *interfaces):
     """Declare the only interfaces implemented by instances of a class
 
-      The arguments after the class are one or more interfaces or
-      interface specifications (IDeclaration objects).
+      The arguments after the class are one or more interfaces or interface
+      specifications (``IDeclaration`` objects).
 
-      The interfaces given (including the interfaces in the
-      specifications) replace any previous declarations.
+      The interfaces given (including the interfaces in the specifications)
+      replace any previous declarations.
 
-      Consider the following example::
+      Consider the following example:
 
-          >>> from zope.interface import Interface
-          >>> class I1(Interface): pass
-          ...
-          >>> class I2(Interface): pass
-          ...
-          >>> class I3(Interface): pass
-          ...
-          >>> class I4(Interface): pass
-          ...
-          >>> class A(object):
-          ...   implements(I3)
-          >>> class B(object):
-          ...   implements(I4)
-          >>> class C(A, B):
-          ...   pass
-          >>> classImplementsOnly(C, I1, I2)
-          >>> [i.getName() for i in implementedBy(C)]
-          ['I1', 'I2']
+        >>> from zope.interface import Interface
+        >>> class I1(Interface): pass
+        ...
+        >>> class I2(Interface): pass
+        ...
+        >>> class I3(Interface): pass
+        ...
+        >>> class I4(Interface): pass
+        ...
+        >>> class A(object):
+        ...   implements(I3)
+        >>> class B(object):
+        ...   implements(I4)
+        >>> class C(A, B):
+        ...   pass
+        >>> classImplementsOnly(C, I1, I2)
+        >>> [i.getName() for i in implementedBy(C)]
+        ['I1', 'I2']
 
       Instances of ``C`` provide only ``I1``, ``I2``, and regardless of
       whatever interfaces instances of ``A`` and ``B`` implement.
-
       """
     spec = implementedBy(cls)
-    spec.__bases__ = tuple(_normalizeargs(interfaces))
+    spec.declared = ()
     spec.inherit = None
+    classImplements(cls, *interfaces)
 
 def classImplements(cls, *interfaces):
     """Declare additional interfaces implemented for instances of a class
 
       The arguments after the class are one or more interfaces or
-      interface specifications (IDeclaration objects).
+      interface specifications (``IDeclaration`` objects).
 
-      The interfaces given (including the interfaces in the
-      specifications) are added to any interfaces previously
-      declared.
+      The interfaces given (including the interfaces in the specifications)
+      are added to any interfaces previously declared.
 
-      Consider the following example::
+      Consider the following example:
 
-
-      for example:
-
-      >>> from zope.interface import Interface
-      >>> class I1(Interface): pass
-      ...
-      >>> class I2(Interface): pass
-      ...
-      >>> class I3(Interface): pass
-      ...
-      >>> class I4(Interface): pass
-      ...
-      >>> class I5(Interface): pass
-      ...
-      >>> class A(object):
-      ...   implements(I3)
-      >>> class B(object):
-      ...   implements(I4)
-      >>> class C(A, B):
-      ...   pass
-      >>> classImplements(C, I1, I2)
-      >>> [i.getName() for i in implementedBy(C)]
-      ['I1', 'I2', 'I3', 'I4']
-      >>> classImplements(C, I5)
-      >>> [i.getName() for i in implementedBy(C)]
-      ['I1', 'I2', 'I5', 'I3', 'I4']
+        >>> from zope.interface import Interface
+        >>> class I1(Interface): pass
+        ...
+        >>> class I2(Interface): pass
+        ...
+        >>> class I3(Interface): pass
+        ...
+        >>> class I4(Interface): pass
+        ...
+        >>> class I5(Interface): pass
+        ...
+        >>> class A(object):
+        ...   implements(I3)
+        >>> class B(object):
+        ...   implements(I4)
+        >>> class C(A, B):
+        ...   pass
+        >>> classImplements(C, I1, I2)
+        >>> [i.getName() for i in implementedBy(C)]
+        ['I1', 'I2', 'I3', 'I4']
+        >>> classImplements(C, I5)
+        >>> [i.getName() for i in implementedBy(C)]
+        ['I1', 'I2', 'I5', 'I3', 'I4']
 
       Instances of ``C`` provide ``I1``, ``I2``, ``I5``, and whatever
       interfaces instances of ``A`` and ``B`` provide.
-
       """
 
     spec = implementedBy(cls)
@@ -476,7 +489,7 @@ def classImplements(cls, *interfaces):
             if b not in seen:
                 seen[b] = 1
                 bases.append(b)
-        
+
     spec.__bases__ = tuple(bases)
 
 def _implements_advice(cls):
@@ -485,6 +498,24 @@ def _implements_advice(cls):
     classImplements(cls, *interfaces)
     return cls
 
+
+class implementer:
+
+    def __init__(self, *interfaces):
+        self.interfaces = interfaces
+
+    def __call__(self, ob):
+        if isinstance(ob, DescriptorAwareMetaClasses):
+            raise TypeError("Can't use implementer with classes.  Use one of "
+                            "the class-declaration functions instead."
+                            )
+        spec = Implements(*self.interfaces)
+        try:
+            ob.__implemented__ = spec
+        except AttributeError:
+            raise TypeError("Can't declare implements", ob)
+        return ob
+
 def _implements(name, interfaces, classImplements):
     frame = sys._getframe(2)
     locals = frame.f_locals
@@ -645,12 +676,12 @@ class Provides(Declaration):  # Really named ProvidesClass
     def __get__(self, inst, cls):
         """Make sure that a class __provides__ doesn't leak to an instance
 
-        For example::
+        For example:
 
           >>> from zope.interface import Interface
           >>> class IFooFactory(Interface): pass
           ...
-          
+
           >>> class C(object):
           ...   pass
 
@@ -667,7 +698,7 @@ class Provides(Declaration):  # Really named ProvidesClass
             # being called on the same class that we were defined for:
             return self
 
-        raise AttributeError, '__provides__'
+        raise AttributeError('__provides__')
 
 ProvidesClass = Provides
 
@@ -678,17 +709,15 @@ InstanceDeclarations = weakref.WeakValueDictionary()
 def Provides(*interfaces):
     """Cache instance declarations
 
-      Instance declarations are shared among instances that have the
-      same declaration.  The declarations are cached in an weak value
-      dictionary.
+      Instance declarations are shared among instances that have the same
+      declaration. The declarations are cached in a weak value dictionary.
 
-      (Note that, in the examples below, we are going to make
-       assertions about the size of the weakvalue dictionary.  For the
-       assertions to be meaningful, we need to force garbage
-       collection to make sure garbage objects are, indeed, removed
-       from the system. Depending on how Python is run, we may need to
-       make multiple calls to be sure.  We provide a collect function
-       to help with this:
+      (Note that, in the examples below, we are going to make assertions about
+       the size of the weakvalue dictionary.  For the assertions to be
+       meaningful, we need to force garbage collection to make sure garbage
+       objects are, indeed, removed from the system. Depending on how Python
+       is run, we may need to make multiple calls to be sure.  We provide a
+       collect function to help with this:
 
        >>> import gc
        >>> def collect():
@@ -696,7 +725,7 @@ def Provides(*interfaces):
        ...         gc.collect()
 
       )
-      
+
       >>> collect()
       >>> before = len(InstanceDeclarations)
 
@@ -706,7 +735,7 @@ def Provides(*interfaces):
       >>> from zope.interface import Interface
       >>> class I(Interface):
       ...    pass
-      
+
       >>> c1 = C()
       >>> c2 = C()
 
@@ -730,9 +759,8 @@ def Provides(*interfaces):
       >>> collect()
       >>> len(InstanceDeclarations) == before
       1
-      
       """
-    
+
     spec = InstanceDeclarations.get(interfaces)
     if spec is None:
         spec = ProvidesClass(*interfaces)
@@ -746,14 +774,13 @@ DescriptorAwareMetaClasses = ClassType, type
 def directlyProvides(object, *interfaces):
     """Declare interfaces declared directly for an object
 
-      The arguments after the object are one or more interfaces or
-      interface specifications (IDeclaration objects).
+      The arguments after the object are one or more interfaces or interface
+      specifications (``IDeclaration`` objects).
 
-      The interfaces given (including the interfaces in the
-      specifications) replace interfaces previously
-      declared for the object.
+      The interfaces given (including the interfaces in the specifications)
+      replace interfaces previously declared for the object.
 
-      Consider the following example::
+      Consider the following example:
 
         >>> from zope.interface import Interface
         >>> class I1(Interface): pass
@@ -795,7 +822,7 @@ def directlyProvides(object, *interfaces):
       instances have been declared for instances of ``C``.
 
       To remove directly provided interfaces, use ``directlyProvidedBy`` and
-      subtract the unwanted interfaces. For example::
+      subtract the unwanted interfaces. For example:
 
         >>> directlyProvides(ob, directlyProvidedBy(ob)-I2)
         >>> int(I1 in providedBy(ob))
@@ -803,19 +830,18 @@ def directlyProvides(object, *interfaces):
         >>> int(I2 in providedBy(ob))
         0
 
-      removes I2 from the interfaces directly provided by
-      ``ob``. The object, ``ob`` no longer directly provides ``I2``,
-      although it might still provide ``I2`` if it's class
-      implements ``I2``.
+      removes I2 from the interfaces directly provided by ``ob``. The object,
+      ``ob`` no longer directly provides ``I2``, although it might still
+      provide ``I2`` if it's class implements ``I2``.
 
       To add directly provided interfaces, use ``directlyProvidedBy`` and
-      include additional interfaces.  For example::
+      include additional interfaces.  For example:
 
         >>> int(I2 in providedBy(ob))
         0
         >>> directlyProvides(ob, directlyProvidedBy(ob), I2)
 
-      adds I2 to the interfaces directly provided by ob::
+      adds ``I2`` to the interfaces directly provided by ob::
 
         >>> int(I2 in providedBy(ob))
         1
@@ -847,73 +873,72 @@ def directlyProvides(object, *interfaces):
         object.__provides__ = ClassProvides(object, cls, *interfaces)
     else:
         object.__provides__ = Provides(cls, *interfaces)
-        
-    
+
+
 def alsoProvides(object, *interfaces):
     """Declare interfaces declared directly for an object
 
-      The arguments after the object are one or more interfaces or
-      interface specifications (IDeclaration objects).
+    The arguments after the object are one or more interfaces or interface
+    specifications (``IDeclaration`` objects).
 
-      The interfaces given (including the interfaces in the
-      specifications) are added to the interfaces previously
-      declared for the object.
-      
-      Consider the following example::
+    The interfaces given (including the interfaces in the specifications) are
+    added to the interfaces previously declared for the object.
 
-        >>> from zope.interface import Interface
-        >>> class I1(Interface): pass
-        ...
-        >>> class I2(Interface): pass
-        ...
-        >>> class IA1(Interface): pass
-        ...
-        >>> class IA2(Interface): pass
-        ...
-        >>> class IB(Interface): pass
-        ...
-        >>> class IC(Interface): pass
-        ...
-        >>> class A(object): implements(IA1, IA2)
-        ...
-        >>> class B(object): implements(IB)
-        ...
+    Consider the following example:
 
-        >>> class C(A, B):
-        ...    implements(IC)
+      >>> from zope.interface import Interface
+      >>> class I1(Interface): pass
+      ...
+      >>> class I2(Interface): pass
+      ...
+      >>> class IA1(Interface): pass
+      ...
+      >>> class IA2(Interface): pass
+      ...
+      >>> class IB(Interface): pass
+      ...
+      >>> class IC(Interface): pass
+      ...
+      >>> class A(object): implements(IA1, IA2)
+      ...
+      >>> class B(object): implements(IB)
+      ...
 
-        >>> ob = C()
-        >>> directlyProvides(ob, I1)
-        >>> int(I1 in providedBy(ob))
-        1
-        >>> int(I2 in providedBy(ob))
-        0
-        >>> int(IA1 in providedBy(ob))
-        1
-        >>> int(IA2 in providedBy(ob))
-        1
-        >>> int(IB in providedBy(ob))
-        1
-        >>> int(IC in providedBy(ob))
-        1
-        
-        >>> alsoProvides(ob, I2)
-        >>> int(I1 in providedBy(ob))
-        1
-        >>> int(I2 in providedBy(ob))
-        1
-        >>> int(IA1 in providedBy(ob))
-        1
-        >>> int(IA2 in providedBy(ob))
-        1
-        >>> int(IB in providedBy(ob))
-        1
-        >>> int(IC in providedBy(ob))
-        1
-        
-      The object, ``ob`` provides ``I1``, ``I2``, and whatever interfaces
-      instances have been declared for instances of ``C``. Notice that the
-      alsoProvides just extends the provided interfaces.
+      >>> class C(A, B):
+      ...    implements(IC)
+
+      >>> ob = C()
+      >>> directlyProvides(ob, I1)
+      >>> int(I1 in providedBy(ob))
+      1
+      >>> int(I2 in providedBy(ob))
+      0
+      >>> int(IA1 in providedBy(ob))
+      1
+      >>> int(IA2 in providedBy(ob))
+      1
+      >>> int(IB in providedBy(ob))
+      1
+      >>> int(IC in providedBy(ob))
+      1
+
+      >>> alsoProvides(ob, I2)
+      >>> int(I1 in providedBy(ob))
+      1
+      >>> int(I2 in providedBy(ob))
+      1
+      >>> int(IA1 in providedBy(ob))
+      1
+      >>> int(IA2 in providedBy(ob))
+      1
+      >>> int(IB in providedBy(ob))
+      1
+      >>> int(IC in providedBy(ob))
+      1
+
+    The object, ``ob`` provides ``I1``, ``I2``, and whatever interfaces
+    instances have been declared for instances of ``C``. Notice that the
+    alsoProvides just extends the provided interfaces.
     """
     directlyProvides(object, directlyProvidedBy(object), *interfaces)
 
@@ -922,7 +947,7 @@ class ClassProvidesBasePy(object):
     def __get__(self, inst, cls):
         if cls is self._cls:
             # We only work if called on the class we were defined for
-            
+
             if inst is None:
                 # We were accessed through a class, so we are the class'
                 # provides spec. Just return this object as is:
@@ -930,7 +955,7 @@ class ClassProvidesBasePy(object):
 
             return self._implements
 
-        raise AttributeError, '__provides__'
+        raise AttributeError('__provides__')
 
 ClassProvidesBase = ClassProvidesBasePy
 
@@ -950,23 +975,21 @@ class ClassProvides(Declaration, ClassProvidesBase):
     we can get declarations for objects without instance-specific
     interfaces a bit quicker.
 
-        For example::
+    For example:
 
-          >>> from zope.interface import Interface
-          >>> class IFooFactory(Interface):
-          ...     pass
-          >>> class IFoo(Interface):
-          ...     pass
-          >>> class C(object):
-          ...     implements(IFoo)
-          ...     classProvides(IFooFactory)
-          >>> [i.getName() for i in C.__provides__]
-          ['IFooFactory']
+      >>> from zope.interface import Interface
+      >>> class IFooFactory(Interface):
+      ...     pass
+      >>> class IFoo(Interface):
+      ...     pass
+      >>> class C(object):
+      ...     implements(IFoo)
+      ...     classProvides(IFooFactory)
+      >>> [i.getName() for i in C.__provides__]
+      ['IFooFactory']
 
-          >>> [i.getName() for i in C().__provides__]
-          ['IFoo']
-
-    
+      >>> [i.getName() for i in C().__provides__]
+      ['IFoo']
     """
 
     def __init__(self, cls, metacls, *interfaces):
@@ -984,8 +1007,7 @@ class ClassProvides(Declaration, ClassProvidesBase):
 def directlyProvidedBy(object):
     """Return the interfaces directly provided by the given object
 
-    The value returned is an IDeclaration.
-
+    The value returned is an ``IDeclaration``.
     """
     provides = getattr(object, "__provides__", None)
     if (provides is None # no spec
@@ -1005,22 +1027,20 @@ def classProvides(*interfaces):
 
       This function is called in a class definition.
 
-      The arguments are one or more interfaces or interface
-      specifications (IDeclaration objects).
+      The arguments are one or more interfaces or interface specifications
+      (``IDeclaration`` objects).
 
-      The given interfaces (including the interfaces in the
-      specifications) are used to create the class's direct-object
-      interface specification.  An error will be raised if the module
-      class has an direct interface specification.  In other words, it is
-      an error to call this function more than once in a class
-      definition.
+      The given interfaces (including the interfaces in the specifications)
+      are used to create the class's direct-object interface specification.
+      An error will be raised if the module class has an direct interface
+      specification. In other words, it is an error to call this function more
+      than once in a class definition.
 
-      Note that the given interfaces have nothing to do with the
-      interfaces implemented by instances of the class.
+      Note that the given interfaces have nothing to do with the interfaces
+      implemented by instances of the class.
 
-      This function is provided for convenience. It provides a more
-      convenient way to call directlyProvidedByProvides for a class. For
-      example::
+      This function is provided for convenience. It provides a more convenient
+      way to call directlyProvidedByProvides for a class. For example::
 
         classProvides(I1)
 
@@ -1030,37 +1050,35 @@ def classProvides(*interfaces):
 
       after the class has been created.
 
-      For example::
+      For example:
 
-            >>> from zope.interface import Interface
-            >>> class IFoo(Interface): pass
-            ...
-            >>> class IFooFactory(Interface): pass
-            ...
-            >>> class C(object):
-            ...   implements(IFoo)
-            ...   classProvides(IFooFactory)
-            >>> [i.getName() for i in C.__providedBy__]
-            ['IFooFactory']
-            >>> [i.getName() for i in C().__providedBy__]
-            ['IFoo']
-
-      if equivalent to::
-
-            >>> from zope.interface import Interface
-            >>> class IFoo(Interface): pass
-            ...
-            >>> class IFooFactory(Interface): pass
-            ...
-            >>> class C(object):
-            ...   implements(IFoo)
-            >>> directlyProvides(C, IFooFactory)
-            >>> [i.getName() for i in C.__providedBy__]
-            ['IFooFactory']
-            >>> [i.getName() for i in C().__providedBy__]
-            ['IFoo']
+        >>> from zope.interface import Interface
+        >>> class IFoo(Interface): pass
+        ...
+        >>> class IFooFactory(Interface): pass
+        ...
+        >>> class C(object):
+        ...   implements(IFoo)
+        ...   classProvides(IFooFactory)
+        >>> [i.getName() for i in C.__providedBy__]
+        ['IFooFactory']
+        >>> [i.getName() for i in C().__providedBy__]
+        ['IFoo']
 
+      if equivalent to:
 
+        >>> from zope.interface import Interface
+        >>> class IFoo(Interface): pass
+        ...
+        >>> class IFooFactory(Interface): pass
+        ...
+        >>> class C(object):
+        ...   implements(IFoo)
+        >>> directlyProvides(C, IFooFactory)
+        >>> [i.getName() for i in C.__providedBy__]
+        ['IFooFactory']
+        >>> [i.getName() for i in C().__providedBy__]
+        ['IFoo']
       """
     frame = sys._getframe(1)
     locals = frame.f_locals
@@ -1088,25 +1106,23 @@ def moduleProvides(*interfaces):
 
     This function is used in a module definition.
 
-    The arguments are one or more interfaces or interface
-    specifications (IDeclaration objects).
+    The arguments are one or more interfaces or interface specifications
+    (``IDeclaration`` objects).
 
-    The given interfaces (including the interfaces in the
-    specifications) are used to create the module's direct-object
-    interface specification.  An error will be raised if the module
-    already has an interface specification.  In other words, it is
-    an error to call this function more than once in a module
-    definition.
+    The given interfaces (including the interfaces in the specifications) are
+    used to create the module's direct-object interface specification.  An
+    error will be raised if the module already has an interface specification.
+    In other words, it is an error to call this function more than once in a
+    module definition.
 
-    This function is provided for convenience. It provides a more
-    convenient way to call directlyProvides. For example::
+    This function is provided for convenience. It provides a more convenient
+    way to call directlyProvides. For example::
 
       moduleImplements(I1)
 
     is equivalent to::
 
       directlyProvides(sys.modules[__name__], I1)
-
     """
     frame = sys._getframe(1)
     locals = frame.f_locals
@@ -1134,92 +1150,89 @@ def ObjectSpecification(direct, cls):
 
     These combine information for the object and for it's classes.
 
-    For example::
+    For example:
 
-        >>> from zope.interface import Interface
-        >>> class I1(Interface): pass
-        ...
-        >>> class I2(Interface): pass
-        ...
-        >>> class I3(Interface): pass
-        ...
-        >>> class I31(I3): pass
-        ...
-        >>> class I4(Interface): pass
-        ...
-        >>> class I5(Interface): pass
-        ...
-        >>> class A(object): implements(I1)
-        ...
-        >>> class B(object): __implemented__ = I2
-        ...
-        >>> class C(A, B): implements(I31)
-        ...
-        >>> c = C()
-        >>> directlyProvides(c, I4)
-        >>> [i.getName() for i in providedBy(c)]
-        ['I4', 'I31', 'I1', 'I2']
-        >>> [i.getName() for i in providedBy(c).flattened()]
-        ['I4', 'I31', 'I3', 'I1', 'I2', 'Interface']
-        >>> int(I1 in providedBy(c))
-        1
-        >>> int(I3 in providedBy(c))
-        0
-        >>> int(providedBy(c).extends(I3))
-        1
-        >>> int(providedBy(c).extends(I31))
-        1
-        >>> int(providedBy(c).extends(I5))
-        0
-        >>> class COnly(A, B): implementsOnly(I31)
-        ...
-        >>> class D(COnly): implements(I5)
-        ...
-        >>> c = D()
-        >>> directlyProvides(c, I4)
-        >>> [i.getName() for i in providedBy(c)]
-        ['I4', 'I5', 'I31']
-        >>> [i.getName() for i in providedBy(c).flattened()]
-        ['I4', 'I5', 'I31', 'I3', 'Interface']
-        >>> int(I1 in providedBy(c))
-        0
-        >>> int(I3 in providedBy(c))
-        0
-        >>> int(providedBy(c).extends(I3))
-        1
-        >>> int(providedBy(c).extends(I1))
-        0
-        >>> int(providedBy(c).extends(I31))
-        1
-        >>> int(providedBy(c).extends(I5))
-        1
-
-
-        nonzero:
-
-        >>> from zope.interface import Interface
-        >>> class I1(Interface):
-        ...     pass
-        >>> class I2(Interface):
-        ...     pass
-        >>> class C(object):
-        ...     implements(I1)
-        >>> c = C()
-        >>> int(bool(providedBy(c)))
-        1
-        >>> directlyProvides(c, I2)
-        >>> int(bool(providedBy(c)))
-        1
-        >>> class C(object):
-        ...     pass
-        >>> c = C()
-        >>> int(bool(providedBy(c)))
-        0
-        >>> directlyProvides(c, I2)
-        >>> int(bool(providedBy(c)))
-        1
+      >>> from zope.interface import Interface
+      >>> class I1(Interface): pass
+      ...
+      >>> class I2(Interface): pass
+      ...
+      >>> class I3(Interface): pass
+      ...
+      >>> class I31(I3): pass
+      ...
+      >>> class I4(Interface): pass
+      ...
+      >>> class I5(Interface): pass
+      ...
+      >>> class A(object): implements(I1)
+      ...
+      >>> class B(object): __implemented__ = I2
+      ...
+      >>> class C(A, B): implements(I31)
+      ...
+      >>> c = C()
+      >>> directlyProvides(c, I4)
+      >>> [i.getName() for i in providedBy(c)]
+      ['I4', 'I31', 'I1', 'I2']
+      >>> [i.getName() for i in providedBy(c).flattened()]
+      ['I4', 'I31', 'I3', 'I1', 'I2', 'Interface']
+      >>> int(I1 in providedBy(c))
+      1
+      >>> int(I3 in providedBy(c))
+      0
+      >>> int(providedBy(c).extends(I3))
+      1
+      >>> int(providedBy(c).extends(I31))
+      1
+      >>> int(providedBy(c).extends(I5))
+      0
+      >>> class COnly(A, B): implementsOnly(I31)
+      ...
+      >>> class D(COnly): implements(I5)
+      ...
+      >>> c = D()
+      >>> directlyProvides(c, I4)
+      >>> [i.getName() for i in providedBy(c)]
+      ['I4', 'I5', 'I31']
+      >>> [i.getName() for i in providedBy(c).flattened()]
+      ['I4', 'I5', 'I31', 'I3', 'Interface']
+      >>> int(I1 in providedBy(c))
+      0
+      >>> int(I3 in providedBy(c))
+      0
+      >>> int(providedBy(c).extends(I3))
+      1
+      >>> int(providedBy(c).extends(I1))
+      0
+      >>> int(providedBy(c).extends(I31))
+      1
+      >>> int(providedBy(c).extends(I5))
+      1
 
+      nonzero:
 
+      >>> from zope.interface import Interface
+      >>> class I1(Interface):
+      ...     pass
+      >>> class I2(Interface):
+      ...     pass
+      >>> class C(object):
+      ...     implements(I1)
+      >>> c = C()
+      >>> int(bool(providedBy(c)))
+      1
+      >>> directlyProvides(c, I2)
+      >>> int(bool(providedBy(c)))
+      1
+      >>> class C(object):
+      ...     pass
+      >>> c = C()
+      >>> int(bool(providedBy(c)))
+      0
+      >>> directlyProvides(c, I2)
+      >>> int(bool(providedBy(c)))
+      1
     """
 
     return Provides(cls, direct)
@@ -1229,7 +1242,7 @@ def getObjectSpecification(ob):
     provides = getattr(ob, '__provides__', None)
     if provides is not None:
         return provides
-    
+
     try:
         cls = ob.__class__
     except AttributeError:
@@ -1249,7 +1262,6 @@ def providedBy(ob):
     except AttributeError:
         # Not set yet. Fall back to lower-level thing that computes it
         return getObjectSpecification(ob)
-    
 
     try:
         # We might have gotten a descriptor from an instance of a
@@ -1290,16 +1302,16 @@ def providedBy(ob):
     return r
 
 class ObjectSpecificationDescriptorPy(object):
-    """Implement the __providedBy__ attribute
+    """Implement the `__providedBy__` attribute
 
-    The __providedBy__ attribute computes the interfaces peovided by
+    The `__providedBy__` attribute computes the interfaces peovided by
     an object.
     """
 
     def __get__(self, inst, cls):
         """Get an object specification for an object
 
-        For example::
+        For example:
 
           >>> from zope.interface import Interface
           >>> class IFoo(Interface): pass
@@ -1318,7 +1330,7 @@ class ObjectSpecificationDescriptorPy(object):
 
         # Get an ObjectSpecification bound to either an instance or a class,
         # depending on how we were accessed.
-        
+
         if inst is None:
             return getObjectSpecification(cls)
 
@@ -1349,7 +1361,7 @@ def _normalizeargs(sequence, output = None):
     else:
         for v in sequence:
             _normalizeargs(v, output)
-            
+
     return output
 
 _empty = Declaration()
@@ -1364,4 +1376,3 @@ else:
     from _zope_interface_coptimizations import ObjectSpecificationDescriptor
 
 objectSpecificationDescriptor = ObjectSpecificationDescriptor()
-    
