@@ -18,7 +18,7 @@ big improvement of the 'BrowserRequest' to 'HTTPRequest' is that is can handle
 HTML form data and convert them into a Python-native format. Even file data is
 packaged into a nice, Python-friendly 'FileUpload' object.
 
-$Id: browser.py 37641 2005-08-01 21:15:22Z srichter $
+$Id: browser.py 39629 2005-10-26 08:10:38Z hdima $
 """
 import re
 from types import ListType, TupleType, StringType, StringTypes
@@ -31,6 +31,7 @@ from zope.publisher.interfaces.browser import IBrowserRequest
 from zope.publisher.interfaces.browser import IDefaultBrowserLayer
 from zope.publisher.interfaces.browser import IBrowserApplicationRequest
 
+from zope.publisher import contenttype
 from zope.publisher.http import HTTPRequest, HTTPResponse
 from zope.publisher.base import BaseRequest
 
@@ -66,7 +67,7 @@ def field2text(v, nl=newlines):
 def field2required(v):
     v = field2string(v)
     if not v.strip():
-        raise ValueError, 'No input for required field<p>'
+        raise ValueError('No input for required field<p>')
     return v
 
 def field2int(v):
@@ -74,25 +75,24 @@ def field2int(v):
         return map(field2int, v)
     v = field2string(v)
     if not v:
-        raise ValueError, 'Empty entry when <strong>integer</strong> expected'
+        raise ValueError('Empty entry when <strong>integer</strong> expected')
     try:
         return int(v)
     except ValueError:
-        raise ValueError, "An integer was expected in the value '%s'" % v
+        raise ValueError("An integer was expected in the value '%s'" % v)
 
 def field2float(v):
     if isinstance(v, __ArrayTypes):
         return map(field2float, v)
     v = field2string(v)
     if not v:
-        raise ValueError, (
+        raise ValueError(
             'Empty entry when <strong>floating-point number</strong> expected')
     try:
         return float(v)
     except ValueError:
-        raise ValueError, (
-                "A floating-point number was expected in the value '%s'" % v
-            )
+        raise ValueError(
+                "A floating-point number was expected in the value '%s'" % v)
 
 def field2long(v):
     if isinstance(v, __ArrayTypes):
@@ -103,11 +103,11 @@ def field2long(v):
     if v and v[-1].upper() == 'L':
         v = v[:-1]
     if not v:
-        raise ValueError, 'Empty entry when <strong>integer</strong> expected'
+        raise ValueError('Empty entry when <strong>integer</strong> expected')
     try:
         return long(v)
     except ValueError:
-        raise ValueError, "A long integer was expected in the value '%s'" % v
+        raise ValueError("A long integer was expected in the value '%s'" % v)
 
 def field2tokens(v):
     return field2string(v).split()
@@ -143,7 +143,7 @@ def registerTypeConverter(field_type, converter, replace=False):
     existing = type_converters.get(field_type)
 
     if existing is not None and not replace:
-        raise KeyError, 'Existing converter for field_type: %s' % field_type
+        raise KeyError('Existing converter for field_type: %s' % field_type)
 
     type_converters[field_type] = converter
 
@@ -182,7 +182,7 @@ class Record(object):
         if key in ('get', 'keys', 'items', 'values', 'copy',
                    'has_key', '__contains__'):
             return getattr(self.__dict__, key)
-        raise AttributeError, key
+        raise AttributeError(key)
 
     def __getitem__(self, key):
         return self.__dict__[key]
@@ -202,28 +202,27 @@ class BrowserRequest(HTTPRequest):
     implements(IBrowserRequest, IBrowserApplicationRequest)
 
     __slots__ = (
-        '__provides__',      # Allow request to directly provide interfaces
-        'form',   # Form data
+        '__provides__', # Allow request to directly provide interfaces
+        'form', # Form data
         'charsets', # helper attribute
         '__meth',
         '__tuple_items',
         '__defaults',
+        '__annotations__',
         )
 
     # Set this to True in a subclass to redirect GET requests when the
     # effective and actual URLs differ.
-    use_redirect = False 
+    use_redirect = False
 
-    def __init__(self, body_instream, outstream, environ, response=None):
+    def __init__(self, body_instream, environ, response=None):
         self.form = {}
         self.charsets = None
-        super(BrowserRequest, self).__init__(
-            body_instream, outstream, environ, response)
+        super(BrowserRequest, self).__init__(body_instream, environ, response)
 
 
-    def _createResponse(self, outstream):
-        # Should be overridden by subclasses
-        return BrowserResponse(outstream)
+    def _createResponse(self):
+        return BrowserResponse()
 
     def _decode(self, text):
         """Try to decode the text using one of the available charsets."""
@@ -282,7 +281,7 @@ class BrowserRequest(HTTPRequest):
         # Check whether this field is a file upload object
         # Note: A field exists for files, even if no filename was
         # passed in and no data was uploaded. Therefore we can only
-        # tell by the empty filename that no upload was made. 
+        # tell by the empty filename that no upload was made.
         key = item.name
         if (hasattr(item, 'file') and hasattr(item, 'filename')
             and hasattr(item,'headers')):
@@ -601,9 +600,8 @@ class TestRequest(BrowserRequest):
     """Browser request with a constructor convenient for testing
     """
 
-    def __init__(self,
-                 body_instream=None, outstream=None, environ=None, form=None,
-                 skin=None,
+    def __init__(self, body_instream=None, environ=None, form=None,
+                 skin=None, outstream=None,
                  **kw):
 
         _testEnv =  {
@@ -613,19 +611,28 @@ class TestRequest(BrowserRequest):
             'GATEWAY_INTERFACE':  'TestFooInterface/1.0',
             }
 
-        if environ:
+        if environ is not None:
+            # BBB: This is backward-compatibility support for the deprecated
+            # output stream.
+            try:
+                environ.get
+            except AttributeError:
+                import warnings
+                warnings.warn("Can't pass output streams to requests anymore. "
+                              "This will go away in Zope 3.4.",
+                              DeprecationWarning,
+                              2)
+                environ, form, skin, outstream = form, skin, outstream, environ
+
             _testEnv.update(environ)
+
         if kw:
             _testEnv.update(kw)
         if body_instream is None:
             from StringIO import StringIO
             body_instream = StringIO('')
 
-        if outstream is None:
-            from StringIO import StringIO
-            outstream = StringIO()
-
-        super(TestRequest, self).__init__(body_instream, outstream, _testEnv)
+        super(TestRequest, self).__init__(body_instream, _testEnv)
         if form:
             self.form.update(form)
 
@@ -643,10 +650,14 @@ class TestRequest(BrowserRequest):
         else:
             directlyProvides(self, IDefaultBrowserLayer)
 
-    def setPrincipal(self, principal):
-        # HTTPRequest needs to notify the HTTPTask of the username.
-        # We don't want to have to stub HTTPTask in the tests.
-        BaseRequest.setPrincipal(self, principal)
+        # BBB: Goes away in 3.4.
+        self.response.outstream = outstream
+
+    # BBB: Remove in 3.4. The super version will be ok.
+    def _createResponse(self):
+        return BBBResponse()
+
+
 
 class BrowserResponse(HTTPResponse):
     """Browser response
@@ -656,58 +667,19 @@ class BrowserResponse(HTTPResponse):
         '_base', # The base href
         )
 
-    def setBody(self, body):
-        """Sets the body of the response
-
-        Sets the return body equal to the (string) argument "body". Also
-        updates the "content-length" return header and sets the status to
-        200 if it has not already been set.
-        """
-        if body is None:
-            return
-
-        if not isinstance(body, StringTypes):
-            body = unicode(body)
-
-        if 'content-type' not in self._headers:
-            c = (self.__isHTML(body) and 'text/html' or 'text/plain')
-            if self._charset is not None:
-                c += ';charset=' + self._charset
-            self.setHeader('content-type', c)
+    def _implicitResult(self, body):
+        content_type = self.getHeader('content-type')
+        if content_type is None:
+            if isHTML(body):
+                content_type = 'text/html'
+            else:
+                content_type = 'text/plain'
             self.setHeader('x-content-type-warning', 'guessed from content')
-            # TODO: emit a warning once all page templates are changed to
-            # specify their content type explicitly.
+            self.setHeader('content-type', content_type)
 
+        body, headers = super(BrowserResponse, self)._implicitResult(body)
         body = self.__insertBase(body)
-        self._body = body
-        self._updateContentLength()
-        if not self._status_set:
-            self.setStatus(200)
-
-
-    def __isHTML(self, str):
-        """Try to determine whether str is HTML or not."""
-        s = str.lstrip().lower()
-        if s.startswith('<!doctype html'):
-            return True
-        if s.startswith('<html') and (s[5:6] in ' >'):
-            return True
-        if s.startswith('<!--'):
-            idx = s.find('<html')
-            return idx > 0 and (s[idx+5:idx+6] in ' >')
-        else:
-            return False
-
-
-    def __wrapInHTML(self, title, content):
-        t = escape(title)
-        return (
-            "<html><head><title>%s</title></head>\n"
-            "<body><h2>%s</h2>\n"
-            "%s\n"
-            "</body></html>\n" %
-            (t, t, content)
-            )
+        return body, headers
 
 
     def __insertBase(self, body):
@@ -716,15 +688,17 @@ class BrowserResponse(HTTPResponse):
         if content_type and not is_text_html(content_type):
             return body
 
-        if getattr(self, '_base', ''):
+        if self.getBase():
             if body:
                 match = start_of_header_search(body)
                 if match is not None:
                     index = match.start(0) + len(match.group(0))
                     ibase = base_re_search(body)
                     if ibase is None:
+                        # Make sure the base URL is not a unicode string.
+                        base = str(self.getBase())
                         body = ('%s\n<base href="%s" />\n%s' %
-                                (body[:index], self._base, body[index:]))
+                                (body[:index], base, body[index:]))
         return body
 
     def getBase(self):
@@ -757,6 +731,43 @@ class BrowserResponse(HTTPResponse):
         super(BrowserResponse, self).reset()
         self._base = ''
 
+class BBBResponse(BrowserResponse):
+
+    def write(self, str):
+        import warnings
+        warnings.warn("write() method does not exist anymore.",
+                      DeprecationWarning,
+                      2)
+        self.outstream.write(str)
+
+    def outputBody(self):
+        import warnings
+        warnings.warn("Can't pass output streams to requests anymore",
+                      DeprecationWarning,
+                      2)
+        self.outstream.write("Status: %s\r\n" % self.getStatusString())
+        headers = self.getHeaders()
+        headers.sort()
+        self.outstream.write(
+            "\r\n".join([("%s: %s" % h) for h in headers])
+            + "\r\n\r\n"
+            )
+        self.outstream.write(''.join(self.getBody()))
+
+
+def isHTML(str):
+     """Try to determine whether str is HTML or not."""
+     s = str.lstrip().lower()
+     if s.startswith('<!doctype html'):
+         return True
+     if s.startswith('<html') and (s[5:6] in ' >'):
+         return True
+     if s.startswith('<!--'):
+         idx = s.find('<html')
+         return idx > 0 and (s[idx+5:idx+6] in ' >')
+     else:
+         return False
+
 def normalize_lang(lang):
     lang = lang.strip().lower()
     lang = lang.replace('_', '-')
@@ -772,30 +783,25 @@ class BrowserLanguages(object):
 
     def getPreferredLanguages(self):
         '''See interface IUserPreferredLanguages'''
-        request = self.request
-        accept_langs = request.get('HTTP_ACCEPT_LANGUAGE', '').split(',')
+        accept_langs = self.request.get('HTTP_ACCEPT_LANGUAGE', '').split(',')
 
         # Normalize lang strings
-        accept_langs = map(normalize_lang, accept_langs)
+        accept_langs = [normalize_lang(l) for l in accept_langs]
         # Then filter out empty ones
-        accept_langs = filter(None, accept_langs)
+        accept_langs = [l for l in accept_langs if l]
 
-        length = len(accept_langs)
         accepts = []
-
         for index, lang in enumerate(accept_langs):
             l = lang.split(';', 2)
 
-            quality = None
+            # If not supplied, quality defaults to 1...
+            quality = 1.0
 
             if len(l) == 2:
                 q = l[1]
                 if q.startswith('q='):
                     q = q.split('=', 2)[1]
                     quality = float(q)
-            else:
-                # If not supplied, quality defaults to 1
-                quality = 1.0
 
             if quality == 1.0:
                 # ... but we use 1.9 - 0.001 * position to
@@ -809,11 +815,9 @@ class BrowserLanguages(object):
         # Filter langs with q=0, which means
         # unwanted lang according to the spec
         # See: http://www.w3.org/Protocols/rfc2616/rfc2616-sec14.html#sec14.4
-        accepts = filter(lambda acc: acc[0], accepts)
+        accepts = [acc for acc in accepts if acc[0]]
 
         accepts.sort()
         accepts.reverse()
 
         return [lang for quality, lang in accepts]
-
-
