@@ -13,15 +13,16 @@
 ##############################################################################
 """Schema Fields
 
-$Id: _field.py 37565 2005-07-29 20:46:23Z srichter $
+$Id: _field.py 41613 2006-02-13 12:15:50Z hdima $
 """
+
 __docformat__ = 'restructuredtext'
-import warnings
+
 import re
 from datetime import datetime, date, timedelta
 from sets import Set as SetType
 
-from zope.interface import classImplements, implements, directlyProvides
+from zope.interface import classImplements, implements
 from zope.interface.interfaces import IInterface, IMethod
 
 from zope.schema.interfaces import IField
@@ -34,21 +35,22 @@ from zope.schema.interfaces import IChoice, ITuple, IList, ISet, IDict
 from zope.schema.interfaces import IPassword, IObject, IDate, ITimedelta
 from zope.schema.interfaces import IURI, IId, IFromUnicode
 from zope.schema.interfaces import ISource, IBaseVocabulary
+from zope.schema.interfaces import IContextSourceBinder
 
 from zope.schema.interfaces import ValidationError, InvalidValue
 from zope.schema.interfaces import WrongType, WrongContainedType, NotUnique
 from zope.schema.interfaces import SchemaNotProvided, SchemaNotFullyImplemented
 from zope.schema.interfaces import InvalidURI, InvalidId, InvalidDottedName
 from zope.schema.interfaces import ConstraintNotSatisfied
-from zope.schema.interfaces import Unbound
 
 from zope.schema._bootstrapfields import Field, Container, Iterable, Orderable
-from zope.schema._bootstrapfields import MinMaxLen
 from zope.schema._bootstrapfields import Text, TextLine, Bool, Int, Password
-from zope.schema._bootstrapfields import MinMaxLen, ValidatedProperty
+from zope.schema._bootstrapfields import MinMaxLen
 from zope.schema.fieldproperty import FieldProperty
 from zope.schema.vocabulary import getVocabularyRegistry
-from zope.schema.vocabulary import SimpleTerm, SimpleVocabulary
+from zope.schema.vocabulary import VocabularyRegistryError
+from zope.schema.vocabulary import SimpleVocabulary
+
 
 # Fix up bootstrap field types
 Field.title       = FieldProperty(IField['title'])
@@ -196,7 +198,6 @@ class Choice(Field):
             assert source is None, (
                 "You cannot specify both source and vocabulary.")
         elif source is not None:
-            assert ISource.providedBy(source)
             vocabulary = source
 
         assert not (values is None and vocabulary is None), (
@@ -211,7 +212,8 @@ class Choice(Field):
         elif isinstance(vocabulary, (unicode, str)):
             self.vocabularyName = vocabulary
         else:
-            assert ISource.providedBy(vocabulary)
+            assert (ISource.providedBy(vocabulary) or 
+                    IContextSourceBinder.providedBy(vocabulary))
             self.vocabulary = vocabulary
         # Before a default value is checked, it is validated. However, a
         # named vocabulary is usually not complete when these fields are
@@ -228,9 +230,14 @@ class Choice(Field):
         """See zope.schema._bootstrapinterfaces.IField."""
         clone = super(Choice, self).bind(object)
         # get registered vocabulary if needed:
-        if clone.vocabulary is None and self.vocabularyName is not None:
+        if IContextSourceBinder.providedBy(self.vocabulary):
+            clone.vocabulary = self.vocabulary(object)
+            assert ISource.providedBy(clone.vocabulary)
+        elif clone.vocabulary is None and self.vocabularyName is not None:
             vr = getVocabularyRegistry()
             clone.vocabulary = vr.get(object, self.vocabularyName)
+            assert ISource.providedBy(clone.vocabulary)
+
         return clone
 
     def fromUnicode(self, str):
@@ -261,7 +268,7 @@ class Choice(Field):
             except VocabularyRegistryError:
                 raise ValueError("Can't validate value without vocabulary")
         if value not in vocabulary:
-            raise ConstraintNotSatisfied, value
+            raise ConstraintNotSatisfied(value)
 
 class InterfaceField(Field):
     __doc__ = IInterfaceField.__doc__
@@ -317,7 +324,7 @@ def _validate_uniqueness(value):
     temp_values = []
     for item in value:
         if item in temp_values:
-            raise NotUnique, item
+            raise NotUnique(item)
 
         temp_values.append(item)
 
@@ -329,7 +336,7 @@ class AbstractCollection(MinMaxLen, Iterable):
         super(AbstractCollection, self).__init__(**kw)
         # whine if value_type is not a field
         if value_type is not None and not IField.providedBy(value_type):
-            raise ValueError, "'value_type' must be field instance."
+            raise ValueError("'value_type' must be field instance.")
         self.value_type = value_type
         self.unique = unique
 
@@ -346,7 +353,7 @@ class AbstractCollection(MinMaxLen, Iterable):
         super(AbstractCollection, self)._validate(value)
         errors = _validate_sequence(self.value_type, value)
         if errors:
-            raise WrongContainedType, errors
+            raise WrongContainedType(errors)
         if self.unique:
             _validate_uniqueness(value)
 
@@ -423,9 +430,9 @@ class Dict(MinMaxLen, Iterable):
         super(Dict, self).__init__(**kw)
         # whine if key_type or value_type is not a field
         if key_type is not None and not IField.providedBy(key_type):
-            raise ValueError, "'key_type' must be field instance."
+            raise ValueError("'key_type' must be field instance.")
         if value_type is not None and not IField.providedBy(value_type):
-            raise ValueError, "'value_type' must be field instance."
+            raise ValueError("'value_type' must be field instance.")
         self.key_type = key_type
         self.value_type = value_type
 
@@ -439,7 +446,7 @@ class Dict(MinMaxLen, Iterable):
             errors = _validate_sequence(self.key_type, value, errors)
 
             if errors:
-                raise WrongContainedType, errors
+                raise WrongContainedType(errors)
 
         finally:
             errors = None
@@ -449,6 +456,7 @@ _isuri = re.compile(
     r"[a-zA-z0-9+.-]+:"   # scheme
     r"\S*$"               # non space (should be pickier)
     ).match
+
 class URI(BytesLine):
     """URI schema field
     """
@@ -470,7 +478,7 @@ class URI(BytesLine):
         if _isuri(value):
             return
 
-        raise InvalidURI, value
+        raise InvalidURI(value)
 
     def fromUnicode(self, value):
         """
@@ -525,7 +533,7 @@ class Id(BytesLine):
         if _isdotted(value) and "." in value:
             return
 
-        raise InvalidId, value
+        raise InvalidId(value)
 
     def fromUnicode(self, value):
         """
@@ -642,12 +650,11 @@ class DottedName(BytesLine):
             raise InvalidDottedName(value)
         dots = value.count(".")
         if dots < self.min_dots:
-            raise InvalidDottedName, \
-                  ("too few dots; %d required" % self.min_dots, value)
+            raise InvalidDottedName("too few dots; %d required" % self.min_dots,
+                                    value)
         if self.max_dots is not None and dots > self.max_dots:
-            raise InvalidDottedName, \
-                  ("too many dots; no more than %d allowed" % self.max_dots,
-                   value)
+            raise InvalidDottedName("too many dots; no more than %d allowed" %
+                                    self.max_dots, value)
 
     def fromUnicode(self, value):
         v = str(value.strip())
