@@ -14,7 +14,7 @@
 ##############################################################################
 """Tests for TALInterpreter.
 
-$Id: test_talinterpreter.py 28489 2004-11-22 16:38:56Z shane $
+$Id: test_talinterpreter.py 39869 2005-11-03 14:23:04Z hdima $
 """
 import os
 import sys
@@ -24,10 +24,18 @@ from StringIO import StringIO
 
 from zope.tal.taldefs import METALError, I18NError, TAL_VERSION
 from zope.tal.htmltalparser import HTMLTALParser
+from zope.tal.talparser import TALParser
 from zope.tal.talinterpreter import TALInterpreter
-from zope.tal.dummyengine import DummyEngine, DummyTranslationDomain
+from zope.tal.dummyengine import DummyEngine
+from zope.tal.dummyengine import MultipleDomainsDummyEngine
+from zope.tal.dummyengine import DummyTranslationDomain
 from zope.tal.tests import utils
-from zope.i18nmessageid import MessageID
+
+# BBB 2005/10/10 -- MessageIDs are to be removed for Zope 3.3
+import zope.deprecation
+zope.deprecation.__show__.off()
+from zope.i18nmessageid import MessageID, Message
+zope.deprecation.__show__.on()
 
 class TestCaseBase(unittest.TestCase):
 
@@ -63,7 +71,7 @@ class MacroErrorsTestCase(TestCaseBase):
 
 
 class MacroFunkyErrorTest(TestCaseBase):
-    
+
     def test_div_in_p_using_macro(self):
         dummy, macros = self._compile('<p metal:define-macro="M">Booh</p>')
         engine = DummyEngine(macros)
@@ -98,30 +106,6 @@ class MacroExtendTestCase(TestCaseBase):
         f.close()
         return data
 
-    def test_acme_extends_pnome(self):
-        # ACME inc. has a document_list template that uses ACME's
-        # common look and feel.  ACME's look and feel is based on the
-        # work of PNOME, Inc., a company that creates Pretty Nice
-        # Object Management Environments for Zope.  This test verifies
-        # that document_list works as expected.
-        result = StringIO()
-        interpreter = TALInterpreter(
-            self.doclist_program, {}, self.engine, stream=result)
-        interpreter()
-        actual = result.getvalue().strip()
-        expected = self._read(('output', 'document_list.html')).strip()
-        self.assertEqual(actual, expected)
-
-    def test_acme_extends_pnome_source(self):
-        # Render METAL attributes in document_list
-        result = StringIO()
-        interpreter = TALInterpreter(
-            self.doclist_program, {}, self.engine, stream=result, tal=False)
-        interpreter()
-        actual = result.getvalue().strip()
-        expected = self._read(('output', 'document_list_source.html')).strip()
-        self.assertEqual(actual, expected)
-
     def test_preview_acme_template(self):
         # An ACME designer is previewing the ACME design.  For the
         # purposes of this use case, extending a macro should act the
@@ -143,13 +127,18 @@ class MacroExtendTestCase(TestCaseBase):
         actual = result.getvalue().strip()
         expected = self._read(('output', 'acme_template_source.html')).strip()
         self.assertEqual(actual, expected)
-        
 
-class I18NCornerTestCase(TestCaseBase):
+
+class I18NCornerTestCaseBase(TestCaseBase):
+
+    def factory(self, msgid, default, mapping={}):
+        raise NotImplementedError("abstract method")
 
     def setUp(self):
         self.engine = DummyEngine()
-        self.engine.setLocal('foo', MessageID('FoOvAlUe', 'default'))
+        # Make sure we'll translate the msgid not its unicode representation
+        self.engine.setLocal('foo',
+            self.factory('FoOvAlUe${empty}', 'default', {'empty': ''}))
         self.engine.setLocal('bar', 'BaRvAlUe')
 
     def _check(self, program, expected):
@@ -162,38 +151,94 @@ class I18NCornerTestCase(TestCaseBase):
     def test_simple_messageid_translate(self):
         # This test is mainly here to make sure our DummyEngine works
         # correctly.
-        program, macros = self._compile('<span tal:content="foo"/>')
+        program, macros = self._compile(
+            '<span i18n:translate="" tal:content="foo"/>')
         self._check(program, '<span>FOOVALUE</span>\n')
 
-        program, macros = self._compile('<span tal:replace="foo"/>')
+        program, macros = self._compile(
+            '<span i18n:translate="" tal:replace="foo"/>')
         self._check(program, 'FOOVALUE\n')
 
+    def test_text_variable_translate(self):
+        program, macros = self._compile(
+            '<span tal:content="bar"/>')
+        self._check(program, '<span>BaRvAlUe</span>\n')
+
+        program, macros = self._compile(
+            '<span i18n:translate="" tal:content="bar"/>')
+        self._check(program, '<span>BARVALUE</span>\n')
+
+        program, macros = self._compile(
+            '<span i18n:translate="" tal:replace="bar"/>')
+        self._check(program, 'BARVALUE\n')
+
+    def test_text_translate(self):
+        program, macros = self._compile(
+            '<span tal:content="string:BaR"/>')
+        self._check(program, '<span>BaR</span>\n')
+
+        program, macros = self._compile(
+            '<span i18n:translate="" tal:content="string:BaR"/>')
+        self._check(program, '<span>BAR</span>\n')
+
+        program, macros = self._compile(
+            '<span i18n:translate="" tal:replace="string:BaR"/>')
+        self._check(program, 'BAR\n')
+
+    def test_structure_text_variable_translate(self):
+        program, macros = self._compile(
+            '<span tal:content="structure bar"/>')
+        self._check(program, '<span>BaRvAlUe</span>\n')
+
+        program, macros = self._compile(
+            '<span i18n:translate="" tal:content="structure bar"/>')
+        self._check(program, '<span>BARVALUE</span>\n')
+
+        program, macros = self._compile(
+            '<span i18n:translate="" tal:replace="structure bar"/>')
+        self._check(program, 'BARVALUE\n')
+
+    def test_structure_text_translate(self):
+        program, macros = self._compile(
+            '<span tal:content="structure string:BaR"/>')
+        self._check(program, '<span>BaR</span>\n')
+
+        program, macros = self._compile(
+            '<span i18n:translate="" tal:content="structure string:BaR"/>')
+        self._check(program, '<span>BAR</span>\n')
+
+        program, macros = self._compile(
+            '<span i18n:translate="" tal:replace="structure string:BaR"/>')
+        self._check(program, 'BAR\n')
+
     def test_replace_with_messageid_and_i18nname(self):
         program, macros = self._compile(
             '<div i18n:translate="" >'
-            '<span tal:replace="foo" i18n:name="foo_name"/>'
+            '<span i18n:translate="" tal:replace="foo" i18n:name="foo_name"/>'
             '</div>')
         self._check(program, '<div>FOOVALUE</div>\n')
 
     def test_pythonexpr_replace_with_messageid_and_i18nname(self):
         program, macros = self._compile(
             '<div i18n:translate="" >'
-            '<span tal:replace="python: foo" i18n:name="foo_name"/>'
+            '<span i18n:translate="" tal:replace="python: foo"'
+            '    i18n:name="foo_name"/>'
             '</div>')
         self._check(program, '<div>FOOVALUE</div>\n')
 
     def test_structure_replace_with_messageid_and_i18nname(self):
         program, macros = self._compile(
             '<div i18n:translate="" >'
-            '<span tal:replace="structure foo" i18n:name="foo_name"/>'
+            '<span i18n:translate="" tal:replace="structure foo"'
+            '    i18n:name="foo_name"/>'
             '</div>')
         self._check(program, '<div>FOOVALUE</div>\n')
 
     def test_complex_replace_with_messageid_and_i18nname(self):
         program, macros = self._compile(
             '<div i18n:translate="" >'
-            '<em i18n:name="foo_name">'
-            '<span tal:replace="foo"/>'
+            '<em tal:omit-tag="" i18n:name="foo_name">'
+            '<span i18n:translate="" tal:replace="foo"/>'
             '</em>'
             '</div>')
         self._check(program, '<div>FOOVALUE</div>\n')
@@ -201,7 +246,7 @@ class I18NCornerTestCase(TestCaseBase):
     def test_content_with_messageid_and_i18nname(self):
         program, macros = self._compile(
             '<div i18n:translate="" >'
-            '<span tal:content="foo" i18n:name="foo_name"/>'
+            '<span i18n:translate="" tal:content="foo" i18n:name="foo_name"/>'
             '</div>')
         self._check(program, '<div><span>FOOVALUE</span></div>\n')
 
@@ -211,6 +256,12 @@ class I18NCornerTestCase(TestCaseBase):
             I18NError, self._compile,
             '<span i18n:translate="" tal:content="foo" i18n:name="foo_name"/>')
 
+    def test_content_with_explicit_messageid(self):
+        # Let's tell the user this is incredibly silly!
+        self.assertRaises(
+            I18NError, self._compile,
+            '<span i18n:translate="ID" tal:content="foo" />')
+
     def test_content_with_plaintext_and_i18nname_and_i18ntranslate(self):
         # Let's tell the user this is incredibly silly!
         self.assertRaises(
@@ -218,6 +269,12 @@ class I18NCornerTestCase(TestCaseBase):
             '<span i18n:translate="" i18n:name="color_name">green</span>')
 
     def test_translate_static_text_as_dynamic(self):
+        program, macros = self._compile(
+            '<div i18n:translate="">This is text for '
+            '<span tal:content="bar" i18n:name="bar_name"/>.'
+            '</div>')
+        self._check(program,
+                    '<div>THIS IS TEXT FOR <span>BaRvAlUe</span>.</div>\n')
         program, macros = self._compile(
             '<div i18n:translate="">This is text for '
             '<span i18n:translate="" tal:content="bar" i18n:name="bar_name"/>.'
@@ -259,19 +316,33 @@ class I18NCornerTestCase(TestCaseBase):
                     '<div>THIS IS TEXT FOR <span>BARVALUE</span>.</div>\n')
 
     def test_for_correct_msgids(self):
+        self.engine.translationDomain.clearMsgids()
+        result = StringIO()
+        #GChapelle: 
+        #I have the feeling the i18n:translate with the i18n:name is wrong
+        #
+        #program, macros = self._compile(
+        #    '<div i18n:translate="">This is text for '
+        #    '<span i18n:translate="" tal:content="bar" '
+        #    'i18n:name="bar_name"/>.</div>')
+        program, macros = self._compile(
+            '<div i18n:translate="">This is text for '
+            '<span tal:content="bar" '
+            'i18n:name="bar_name"/>.</div>')
+        self.interpreter = TALInterpreter(program, {}, self.engine,
+                                          stream=result)
+        self.interpreter()
+        msgids = self.engine.translationDomain.getMsgids('default')
+        msgids.sort()
+        self.assertEqual(1, len(msgids))
+        self.assertEqual('This is text for ${bar_name}.', msgids[0][0])
+        self.assertEqual({'bar_name': '<span>BaRvAlUe</span>'}, msgids[0][1])
+        self.assertEqual(
+            '<div>THIS IS TEXT FOR <span>BaRvAlUe</span>.</div>\n',
+            result.getvalue())
 
-        class CollectingTranslationDomain(DummyTranslationDomain):
-            data = []
-
-            def translate(self, msgid, mapping=None,
-                          context=None, target_language=None, default=None):
-                self.data.append(msgid)
-                return DummyTranslationDomain.translate(
-                    self,
-                    msgid, mapping, context, target_language, default)
-
-        xlatdmn = CollectingTranslationDomain()
-        self.engine.translationDomain = xlatdmn
+    def test_for_correct_msgids_translate_name(self):
+        self.engine.translationDomain.clearMsgids()
         result = StringIO()
         program, macros = self._compile(
             '<div i18n:translate="">This is text for '
@@ -280,13 +351,102 @@ class I18NCornerTestCase(TestCaseBase):
         self.interpreter = TALInterpreter(program, {}, self.engine,
                                           stream=result)
         self.interpreter()
-        self.assert_('BaRvAlUe' in xlatdmn.data)
-        self.assert_('This is text for ${bar_name}.' in
-                     xlatdmn.data)
+        msgids = self.engine.translationDomain.getMsgids('default')
+        msgids.sort()
+        self.assertEqual(2, len(msgids))
+        self.assertEqual('This is text for ${bar_name}.', msgids[1][0])
+        self.assertEqual({'bar_name': '<span>BARVALUE</span>'}, msgids[1][1])
         self.assertEqual(
             '<div>THIS IS TEXT FOR <span>BARVALUE</span>.</div>\n',
             result.getvalue())
 
+    def test_i18ntranslate_i18nname_and_attributes(self):
+        # Test for Issue 301: Bug with i18n:name and i18n:translate
+        # on the same element
+        self.engine.translationDomain.clearMsgids()
+        result = StringIO()
+        program, macros = self._compile(
+            '<p i18n:translate="">'
+            'Some static text and a <a tal:attributes="href string:url"'
+            ' i18n:name="link" i18n:translate="">link text</a>.</p>')
+        self.interpreter = TALInterpreter(program, {}, self.engine,
+                                          stream=result)
+        self.interpreter()
+        msgids = self.engine.translationDomain.getMsgids('default')
+        msgids.sort()
+        self.assertEqual(2, len(msgids))
+        self.assertEqual('Some static text and a ${link}.', msgids[0][0])
+        self.assertEqual({'link': '<a href="url">LINK TEXT</a>'}, msgids[0][1])
+        self.assertEqual('link text', msgids[1][0])
+        self.assertEqual(
+            '<p>SOME STATIC TEXT AND A <a href="url">LINK TEXT</a>.</p>\n',
+            result.getvalue())
+
+    def test_for_raw_msgids(self):
+        # Test for Issue 314: i18n:translate removes line breaks from
+        # <pre>...</pre> contents
+        # HTML mode
+        self.engine.translationDomain.clearMsgids()
+        result = StringIO()
+        program, macros = self._compile(
+            '<div i18n:translate=""> This is text\n'
+            ' \tfor\n div. </div>'
+            '<pre i18n:translate=""> This is text\n'
+            ' <b>\tfor</b>\n pre. </pre>')
+        self.interpreter = TALInterpreter(program, {}, self.engine,
+                                          stream=result)
+        self.interpreter()
+        msgids = self.engine.translationDomain.getMsgids('default')
+        msgids.sort()
+        self.assertEqual(2, len(msgids))
+        self.assertEqual(' This is text\n <b>\tfor</b>\n pre. ', msgids[0][0])
+        self.assertEqual('This is text for div.', msgids[1][0])
+        self.assertEqual(
+            '<div>THIS IS TEXT FOR DIV.</div>'
+            '<pre> THIS IS TEXT\n <B>\tFOR</B>\n PRE. </pre>\n',
+            result.getvalue())
+
+        # XML mode
+        self.engine.translationDomain.clearMsgids()
+        result = StringIO()
+        parser = TALParser()
+        parser.parseString(
+            '<?xml version="1.0"?>\n'
+            '<pre xmlns:i18n="http://xml.zope.org/namespaces/i18n"'
+            ' i18n:translate=""> This is text\n'
+            ' <b>\tfor</b>\n barvalue. </pre>')
+        program, macros = parser.getCode()
+        self.interpreter = TALInterpreter(program, {}, self.engine,
+                                          stream=result)
+        self.interpreter()
+        msgids = self.engine.translationDomain.getMsgids('default')
+        msgids.sort()
+        self.assertEqual(1, len(msgids))
+        self.assertEqual('This is text <b> for</b> barvalue.', msgids[0][0])
+        self.assertEqual(
+            '<?xml version="1.0"?>\n'
+            '<pre>THIS IS TEXT <B> FOR</B> BARVALUE.</pre>\n',
+            result.getvalue())
+
+    def test_raw_msgids_and_i18ntranslate_i18nname(self):
+        self.engine.translationDomain.clearMsgids()
+        result = StringIO()
+        program, macros = self._compile(
+            '<div i18n:translate=""> This is text\n \tfor\n'
+            '<pre i18n:name="bar" i18n:translate=""> \tbar\n </pre>.</div>')
+        self.interpreter = TALInterpreter(program, {}, self.engine,
+                                          stream=result)
+        self.interpreter()
+        msgids = self.engine.translationDomain.getMsgids('default')
+        msgids.sort()
+        self.assertEqual(2, len(msgids))
+        self.assertEqual(' \tbar\n ', msgids[0][0])
+        self.assertEqual('This is text for ${bar}.', msgids[1][0])
+        self.assertEqual({'bar': '<pre> \tBAR\n </pre>'}, msgids[1][1])
+        self.assertEqual(
+            u'<div>THIS IS TEXT FOR <pre> \tBAR\n </pre>.</div>\n',
+            result.getvalue())
+
     def test_for_handling_unicode_vars(self):
         # Make sure that non-ASCII Unicode is substituted correctly.
         # http://collector.zope.org/Zope3-dev/264
@@ -295,6 +455,93 @@ class I18NCornerTestCase(TestCaseBase):
             "Foo <span tal:replace='bar' i18n:name='bar' /></div>")
         self._check(program, u"<div>FOO \u00C0</div>\n")
 
+    
+class I18NCornerTestCaseMessageID(I18NCornerTestCaseBase):
+
+    def factory(self, msgid, default=None, mapping={}, domain=None):
+        m = MessageID(msgid, default=default)
+        m.mapping = mapping
+        return m
+
+class UnusedExplicitDomainTestCase(I18NCornerTestCaseMessageID):
+    
+    def factory(self, msgid, default=None, mapping={}, domain=None):
+        m = MessageID(msgid, default=default, domain=domain)
+        m.mapping = mapping
+        return m
+
+    
+    def setUp(self):
+        # MultipleDomainsDummyEngine is a Engine
+        # where default domain transforms to uppercase
+        self.engine = MultipleDomainsDummyEngine()
+        self.engine.setLocal('foo',
+            self.factory('FoOvAlUe${empty}', 'default', {'empty': ''}))
+        self.engine.setLocal('bar', 'BaRvAlUe')
+        self.engine.setLocal('baz',
+            self.factory('BaZvAlUe', 'default', {}))
+        # Message ids with different domains
+        self.engine.setLocal('toupper',
+            self.factory('ToUpper', 'default', {}))
+        self.engine.setLocal('tolower',
+            self.factory('ToLower', 'default', {}, domain='lower'))
+
+    def test_multiple_domains(self):
+        program, macros = self._compile(
+            '<div i18n:translate=""'
+            '     tal:content="toupper" />')
+        self._check(program, '<div>TOUPPER</div>\n')
+        program, macros = self._compile(
+            '<div i18n:translate=""'
+            '     tal:content="tolower" />')
+        self._check(program, '<div>tolower</div>\n')
+        program, macros = self._compile(
+            '<div i18n:translate=""'
+            '     tal:content="string:ToUpper" />')
+        self._check(program, '<div>TOUPPER</div>\n')
+        program, macros = self._compile(
+            '<div i18n:translate=""'
+            '     i18n:domain="lower"'
+            '     tal:content="string:ToLower" />')
+        self._check(program, '<div>tolower</div>\n')
+        program, macros = self._compile(
+            '<div i18n:translate=""'
+            '     tal:define="msgid string:ToUpper"'
+            '     tal:content="msgid" />')
+        self._check(program, '<div>TOUPPER</div>\n')
+        program, macros = self._compile(
+            '<div i18n:translate=""'
+            '     i18n:domain="lower"'
+            '     tal:define="msgid string:ToLower"'
+            '     tal:content="msgid" />')
+        self._check(program, '<div>tolower</div>\n')
+
+    def test_unused_explicit_domain(self):
+        #a_very_explicit_domain_setup_by_template_developer_that_wont_be_taken_into_account_by_the_ZPT_engine 
+        #is a domain that transforms to lowercase
+        self.engine.setLocal('othertolower',
+            self.factory('OtherToLower', 'a_very_explicit_domain_setup_by_template_developer_that_wont_be_taken_into_account_by_the_ZPT_engine', {}, domain='lower'))
+        program, macros = self._compile(
+            '<div i18n:translate=""'
+            '     tal:content="othertolower" />')
+        self._check(program, '<div>othertolower</div>\n')
+        #takes domain into account for strings
+        program, macros = self._compile(
+            '<div i18n:translate=""'
+            '     i18n:domain="a_very_explicit_domain_setup_by_template_developer_that_wont_be_taken_into_account_by_the_ZPT_engine"'
+            '     tal:content="string:ToLower" />')
+        self._check(program, '<div>tolower</div>\n')
+        #but not for messageids
+        program, macros = self._compile(
+            '<div i18n:translate=""'
+            '     i18n:domain="a_very_explicit_domain_setup_by_template_developer_that_wont_be_taken_into_account_by_the_ZPT_engine"'
+            '     tal:content="baz" />')
+        self._check(program, '<div>BAZVALUE</div>\n')
+
+class I18NCornerTestCaseMessage(I18NCornerTestCaseBase):
+
+    def factory(self, msgid, default=None, mapping={}):
+        return Message(msgid, default=default, mapping=mapping)
 
 class ScriptTestCase(TestCaseBase):
 
@@ -515,7 +762,9 @@ def test_suite():
     suite.addTest(unittest.makeSuite(MacroExtendTestCase))
     suite.addTest(unittest.makeSuite(OutputPresentationTestCase))
     suite.addTest(unittest.makeSuite(ScriptTestCase))
-    suite.addTest(unittest.makeSuite(I18NCornerTestCase))
+    suite.addTest(unittest.makeSuite(I18NCornerTestCaseMessageID))
+    suite.addTest(unittest.makeSuite(I18NCornerTestCaseMessage))
+    suite.addTest(unittest.makeSuite(UnusedExplicitDomainTestCase))
     suite.addTest(unittest.makeSuite(TestSourceAnnotations))
 
     # TODO: Deactivated test, since we have not found a solution for this and
