@@ -13,7 +13,7 @@
 ##############################################################################
 """Default TALES expression implementations tests.
 
-$Id: test_expressions.py 30451 2005-05-20 04:54:15Z fdrake $
+$Id: test_expressions.py 40270 2005-11-20 13:23:13Z shh $
 """
 import unittest
 
@@ -260,7 +260,7 @@ class FunctionTests(ExpressionTestBase):
         try:
             expr = self.engine.compile('adapterTest/namespace:title')
             expr(self.context)
-        except (NameError,KeyError),e: 
+        except KeyError,e: 
             self.assertEquals(e.args[0],'title')
         else:
             self.fail('Engine accepted unknown function')
