@@ -22,7 +22,7 @@ Main SchoolBell script.
 This module is not necessary if you use SchoolBell as a Zope 3 content object.
 It is only used by the standalone SchoolBell executable.
 
-$Id: main.py 4739 2005-08-16 17:18:57Z mg $
+$Id: main.py 5747 2006-02-10 16:42:50Z mg $
 """
 
 import os
@@ -46,7 +46,7 @@ from zope.i18n import translate
 from zope.publisher.interfaces.http import IHTTPRequest
 from zope.i18n.interfaces import IUserPreferredLanguages
 from zope.app.server.main import run
-from zope.app.server.http import http
+from zope.app.server.wsgi import http
 from zope.app.appsetup import DatabaseOpened, ProcessStarting
 from zope.app.publication.zopepublication import ZopePublication
 from zope.app.traversing.interfaces import IContainmentRoot
@@ -314,6 +314,7 @@ SCHOOLBELL_SITE_DEFINITION = """\
   <include package="zope.app.session" />
   <include package="zope.app.server" />
   <include package="zope.app.http" />
+  <include package="zope.app.authentication" />
 
   <!-- Workaround to shut down a DeprecationWarning that appears because we do
        not include zope.app.onlinehelp and the rotterdam skin tries to look for
