@@ -19,7 +19,7 @@
 """
 Tests for schollbell.rest.app
 
-$Id: test_app.py 4342 2005-07-25 16:02:24Z bskahan $
+$Id: test_app.py 5747 2006-02-10 16:42:50Z mg $
 """
 
 import unittest
@@ -37,7 +37,6 @@ from zope.app.traversing.interfaces import IContainmentRoot
 from zope.app.container.interfaces import INameChooser
 from zope.app.component.testing import PlacefulSetup
 from zope.publisher.browser import TestRequest
-from zope.publisher.interfaces.http import IHTTPRequest
 
 import zope
 
@@ -501,7 +500,8 @@ class TestGroupView(ApplicationObjectViewTestMixin, unittest.TestCase):
         self.assertEquals(response.getHeader('content-type'),
                           "text/xml; charset=UTF-8")
         self.assertEqualsXML(result,
-            """<group xmlns:xlink="http://www.w3.org/1999/xlink">
+            """<group xmlns="http://schooltool.org/ns/model/0.1"
+                      xmlns:xlink="http://www.w3.org/1999/xlink">
                    <title>Root group</title>
                    <description/>
                    <relationships xlink:href="http://127.0.0.1/groups/root/relationships"
@@ -526,7 +526,8 @@ class TestGroupView(ApplicationObjectViewTestMixin, unittest.TestCase):
         self.assertEquals(response.getHeader('content-type'),
                           "text/xml; charset=UTF-8")
         self.assertEqualsXML(result,
-            """<group xmlns:xlink="http://www.w3.org/1999/xlink">
+            """<group  xmlns="http://schooltool.org/ns/model/0.1"
+                       xmlns:xlink="http://www.w3.org/1999/xlink">
                    <title>Root group</title>
                    <description>Foo</description>
                    <relationships xlink:href="http://127.0.0.1/groups/root/relationships"
@@ -653,7 +654,8 @@ class TestPersonView(ApplicationObjectViewTestMixin, unittest.TestCase):
         self.assertEquals(response.getHeader('content-type'),
                           "text/xml; charset=UTF-8")
         self.assertEqualsXML(result,
-            """<person xmlns:xlink="http://www.w3.org/1999/xlink">
+            """<person xmlns="http://schooltool.org/ns/model/0.1"
+                       xmlns:xlink="http://www.w3.org/1999/xlink">
                    <title>Root person</title>
                    <relationships xlink:href="http://127.0.0.1/persons/root/relationships"
                                   xlink:title="Relationships" xlink:type="simple"/>
@@ -776,8 +778,7 @@ class TestPersonPhotoView(ApplicationObjectViewTestMixin,
         response = view.request.response
 
         self.assertEquals(response.getStatus(), 200)
-        self.assertEquals(result, response)
-        self.assert_(result._outstream.getvalue().endswith("Icky Picky"))
+        self.assert_(result.endswith("Icky Picky"))
 
     def testPUT(self):
 
@@ -813,12 +814,7 @@ def doctest_CalendarView():
         >>> calendar = person.calendar
         >>> view = CalendarView(calendar, TestRequest())
 
-        >>> print view.GET()._outstream.getvalue().replace("\r\n", "\n")
-        Status: 200 Ok
-        Content-Length: ...
-        Content-Type: text/calendar; charset=UTF-8
-        X-Powered-By: Zope (www.zope.org), Python (www.python.org)
-        <BLANKLINE>
+        >>> print view.GET().replace("\r\n", "\n")
         BEGIN:VCALENDAR
         VERSION:2.0
         PRODID:-//SchoolTool.org/NONSGML SchoolBell//EN
@@ -858,6 +854,40 @@ def doctest_CalendarView():
     """
 
 
+def doctest_CalendarOwnerHttpTraverser():
+    """Tests for CalendarOwnerHttpTraverser.
+
+    CalendarOwnerHttpTraverser allows you to traverse directly to the calendar
+    of a calendar owner.
+
+        >>> from schoolbell.app.rest.app import CalendarOwnerHTTPTraverser
+        >>> from schoolbell.app.app import Person
+        >>> person = Person()
+        >>> request = TestRequest()
+        >>> traverser = CalendarOwnerHTTPTraverser(person, request)
+        >>> traverser.context is person
+        True
+        >>> traverser.request is request
+        True
+
+    The traverser should implement IBrowserPublisher:
+
+        >>> from zope.publisher.interfaces.browser import IBrowserPublisher
+        >>> verifyObject(IBrowserPublisher, traverser)
+        True
+
+    The whole point of this class is that we can ask for the calendar:
+
+        >>> traverser.publishTraverse(request, 'calendar') is person.calendar
+        True
+        >>> traverser.publishTraverse(request, 'calendar.ics') is person.calendar
+        True
+        >>> traverser.publishTraverse(request, 'calendar.vfb') is person.calendar
+        True
+
+    """
+
+
 def doctest_PersonHttpTraverser():
     """Tests for PersonHttpTraverser.
 
