@@ -19,13 +19,16 @@
 """
 Unit tests for schoolbell.calendar.recurrent.
 
-$Id: test_recurrent.py 5021 2005-09-20 09:24:55Z mg $
+$Id: test_recurrent.py 5754 2006-02-11 17:52:04Z ignas $
 """
 
 import time
 import unittest
+
+import pytz
 from datetime import datetime, date, timedelta
 from zope.interface.verify import verifyObject
+from zope.testing import doctest
 
 
 class RecurrenceRuleTestBase:
@@ -304,6 +307,7 @@ class TestYearlyRecurrenceRule(unittest.TestCase, RecurrenceRuleTestBase):
         self.assertEqual(rule._scroll(ev, date(2004, 3, 1)),
                          (8, date(2004, 2, 29)))
 
+
 class TestWeeklyRecurrenceRule(unittest.TestCase, RecurrenceRuleTestBase):
 
     def createRule(self, *args, **kwargs):
@@ -357,7 +361,7 @@ class TestWeeklyRecurrenceRule(unittest.TestCase, RecurrenceRuleTestBase):
                        (6, date(1978, 6, 7)),
                        (7, date(1978, 6, 8))]
 
-        for delta in range(40):
+        for delta in range(-10, 40):
             d = date(1978, 5, 17) + date.resolution * delta
             self.assert_(rule._scroll(ev, d) in goodresults, d)
 
@@ -542,6 +546,21 @@ class TestMonthlyRecurrenceRule(unittest.TestCase, RecurrenceRuleTestBase):
                                   date(2001, 7, 31),
                                   date(2002, 1, 31),])
 
+    def test_apply_weekday_edge_case(self):
+        # A test for Issue381 (monthly repeat causes bad date)
+        from schoolbell.calendar.simple import SimpleCalendarEvent
+        rule = self.createRule(monthly="weekday")
+        # 1st Tuesday and 7th day of the week
+        ev = SimpleCalendarEvent(datetime(2006, 2, 7, 12, 0),
+                           timedelta(minutes=10),
+                           "reality check", unique_id='uid')
+
+        result = list(rule.apply(ev, enddate=date(2006, 5, 10)))
+        expected = [date(2006, 2, 7), date(2006, 3, 7),
+                    date(2006, 4, 4), date(2006, 5, 2)]
+        self.assertEqual(result, expected)
+
+
     def test_apply_weekday(self):
         from schoolbell.calendar.simple import SimpleCalendarEvent
         rule = self.createRule(monthly="weekday")
@@ -782,8 +801,25 @@ class TestMonthIndex(unittest.TestCase):
         self.assertEqual(monthindex(2004, 12, -2, 3), date(2004, 12, 23))
 
 
+def doctest_InfinitePastEventsBug():
+    """Regression test for http://issues.schooltool.org/issue461
+
+        >>> from schoolbell.calendar.simple import SimpleCalendarEvent
+        >>> from schoolbell.calendar.recurrent import WeeklyRecurrenceRule
+        >>> ev = SimpleCalendarEvent(datetime(2006, 1, 18, tzinfo=pytz.utc),
+        ...                          timedelta(hours=1), 'Sample event',
+        ...                          recurrence=WeeklyRecurrenceRule())
+        >>> for e in ev.expand(datetime(2006, 1, 1, tzinfo=pytz.utc),
+        ...                    datetime(2006, 2, 1, tzinfo=pytz.utc)):
+        ...     print e.dtstart
+        2006-01-18 00:00:00+00:00
+        2006-01-25 00:00:00+00:00
+
+    """
+
 def test_suite():
     suite = unittest.TestSuite()
+    suite.addTest(doctest.DocTestSuite())
     suite.addTest(unittest.makeSuite(TestDailyRecurrenceRule))
     suite.addTest(unittest.makeSuite(TestYearlyRecurrenceRule))
     suite.addTest(unittest.makeSuite(TestWeeklyRecurrenceRule))
