@@ -20,10 +20,10 @@
 SchoolTool libraries and application
 """
 
-VERSION = "0.11.2"
+VERSION = "0.11.4"
 
-from zope.i18n import MessageIDFactory
-SchoolToolMessageID = MessageIDFactory("schooltool")
+from zope.i18n import MessageFactory
+SchoolToolMessage = MessageFactory("schooltool")
 
 
 
