@@ -19,7 +19,7 @@
 """
 SchoolTool application
 
-$Id: app.py 4764 2005-08-17 11:05:32Z gintas $
+$Id: app.py 5752 2006-02-11 14:41:40Z ignas $
 
 """
 
@@ -39,6 +39,7 @@ from zope.app.security.interfaces import IUnauthenticatedGroup
 
 from schoolbell.relationship import RelationshipProperty
 from schoolbell.relationship.relationship import BoundRelationshipProperty
+from schoolbell.relationship.interfaces import IRelationshipAddedEvent
 from schoolbell.app.interfaces import IHaveNotes, IApplicationPreferences
 from schoolbell.app.cal import Calendar
 from schoolbell.app.membership import URIMembership, URIGroup, URIMember
@@ -46,9 +47,11 @@ from schoolbell.app.overlay import choose_color, DEFAULT_COLORS
 from schoolbell.app.overlay import OverlaidCalendarsProperty
 from schoolbell.app.overlay import BoundOverlaidCalendarsProperty
 from schoolbell.app.overlay import CalendarOverlayInfo
+from schoolbell.app.overlay import URICalendarSubscription
+from schoolbell.app.overlay import URICalendarProvider
 from schoolbell.app import app as sb
 
-from schooltool import SchoolToolMessageID as _
+from schooltool import SchoolToolMessage as _
 from schooltool.interfaces import ISchoolToolApplication
 from schooltool.interfaces import IPersonContainer, IGroupContainer
 from schooltool.interfaces import IResourceContainer
@@ -158,7 +161,7 @@ class BoundOverlaidCalendarsAndTTProperty(BoundOverlaidCalendarsProperty):
 
     """
 
-    def add(self, calendar, show=True, show_timetables=True,
+    def add(self, calendar, show=True, show_timetables=False,
             color1=None, color2=None):
         if not color1 or not color2:
             used_colors = [(item.color1, item.color2) for item in self]
@@ -204,6 +207,16 @@ class CalendarAndTTOverlayInfo(CalendarOverlayInfo):
         self.color2 = color2
 
 
+def subscribeToPersonTimetables(event):
+    """Include timetables with Person calendar overlays."""
+    if not IRelationshipAddedEvent.providedBy(event):
+        return
+    if event.rel_type != URICalendarSubscription:
+        return
+    if IPerson.providedBy(event[URICalendarProvider].__parent__):
+        event.extra_info.show_timetables = True
+
+
 class Person(sb.Person, TimetabledMixin):
 
     implements(IPerson)
@@ -267,8 +280,8 @@ class Section(Persistent, Contained, TimetabledMixin):
     def _getLabel(self):
         instructors = " ".join([i.title for i in self.instructors])
         courses = " ".join([c.title for c in self.courses])
-        msg = _('${instructors} -- ${courses}')
-        msg.mapping = {'instructors': instructors, 'courses': courses}
+        msg = _('${instructors} -- ${courses}',
+                mapping={'instructors': instructors, 'courses': courses})
         return msg
 
     label = property(_getLabel)
