@@ -19,7 +19,7 @@
 """
 SchoolTool application views.
 
-$Id: csvimport.py 4416 2005-07-31 18:06:55Z bskahan $
+$Id: csvimport.py 5752 2006-02-11 14:41:40Z ignas $
 """
 
 import csv
@@ -29,7 +29,7 @@ from zope.security.proxy import removeSecurityProxy
 
 from schoolbell.app.browser import csvimport as sb
 
-from schooltool import SchoolToolMessageID as _
+from schooltool import SchoolToolMessage as _
 from schooltool import getSchoolToolApplication
 from schooltool.interfaces import ISectionContainer
 from schooltool.app import Person, Section, Course, Group, Resource
@@ -168,8 +168,8 @@ class TimetableCSVImporter(object):
             else:
                 err_msg = _('Malformed line ${line_no} (it should contain a'
                             ' day id, a period id and optionally a location'
-                            ' id)')
-                err_msg.mapping = {'line_no': line + line_ofs - 1}
+                            ' id)',
+                            mapping={'line_no': line + line_ofs - 1})
                 self.errors.generic.append(err_msg)
                 continue
 
@@ -178,8 +178,8 @@ class TimetableCSVImporter(object):
                 try:
                     location = self.app['resources'][location_id]
                 except KeyError:
+                    location = invalid_location
                     if location_id not in self.errors.locations:
-                        location = invalid_location
                         self.errors.locations.append(location_id)
             else:
                 location = None
@@ -201,8 +201,8 @@ class TimetableCSVImporter(object):
             periods.append((day_id, period_id, location))
 
         if not finished or len(rows) == line_ofs:
-            err_msg = _("Incomplete section description on line ${line}")
-            err_msg.mapping = {'line': line}
+            err_msg = _("Incomplete section description on line ${line}",
+                        mapping = {'line': line})
             self.errors.generic.append(err_msg)
             return
 
@@ -296,15 +296,15 @@ class TimetableCSVImporter(object):
         try:
             self.term = self.app['terms'][term_id]
         except KeyError:
-            error_msg = _("The term ${term} does not exist.")
-            error_msg.mapping = {'term': term_id}
+            error_msg = _("The term ${term} does not exist.",
+                          mapping={'term': term_id})
             self.errors.generic.append(error_msg)
 
         try:
             self.ttschema = self.app['ttschemas'][ttschema_id]
         except KeyError:
-            error_msg = _("The timetable schema ${schema} does not exist.")
-            error_msg.mapping = {'schema': ttschema_id}
+            error_msg = _("The timetable schema ${schema} does not exist.",
+                          mapping={'schema': ttschema_id})
             self.errors.generic.append(error_msg)
 
     def parseCSVRows(self, rows):
@@ -334,13 +334,13 @@ class TimetableCSVImporter(object):
         except StopIteration:
             return result
         except csv.Error:
-            error_msg = _("Error in timetable CSV data, line ${line_no}")
-            error_msg.mapping = {'line_no': line}
+            error_msg = _("Error in timetable CSV data, line ${line_no}",
+                          mapping={'line_no': line})
             self.errors.generic.append(error_msg)
             raise InvalidCSVError()
         except UnicodeError:
-            error_msg = _("Conversion to unicode failed in line ${line_no}")
-            error_msg.mapping = {'line_no': line}
+            error_msg = _("Conversion to unicode failed in line ${line_no}",
+                          mapping={'line_no': line})
             self.errors.generic.append(error_msg)
             raise InvalidCSVError()
 
@@ -383,7 +383,7 @@ class TimetableCSVImportView(sb.BaseCSVImportView):
             v = getattr(err, key)
             if v:
                 values = ', '.join([unicode(st) for st in v])
-                msg.mapping = {'args': values}
+                msg = _(msg, mapping={'args': values})
                 self.errors.append(msg)
 
 
@@ -459,7 +459,7 @@ class PersonCSVImporter(sb.PersonCSVImporter):
 
         if not data[0]:
             self.errors.fields.append(_("username may not be empty"))
-            return 
+            return
 
         if not data[1]:
             self.errors.fields.append(_("fullname may not be empty"))
@@ -472,8 +472,8 @@ class PersonCSVImporter(sb.PersonCSVImporter):
             password = None
 
         if username in self.container:
-            error_msg = _("Duplicate username: ${username}")
-            error_msg.mapping = {'username': ', '.join(data)}
+            error_msg = _("Duplicate username: ${username}",
+                          mapping={'username': ', '.join(data)})
             self.errors.fields.append(error_msg)
             return
 
