@@ -41,8 +41,8 @@ class AddingStub(Adding):
     pass
 
 
-def doctest_SchoolBellApplicationView():
-    r"""Test for SchoolBellApplicationView
+def doctest_SchoolToolApplicationView():
+    r"""Test for SchoolToolApplicationView
 
     Some setup
 
@@ -76,7 +76,7 @@ def doctest_SchoolBellApplicationView():
 
         >>> request.response.getStatus()
         302
-        >>> request.response.getHeaders()['Location']
+        >>> request.response.getHeader('Location')
         'http://127.0.0.1/calendar'
 
     If we change a the front page preference, we should not be redirected
@@ -450,7 +450,7 @@ def doctest_SectionEditView():
         u'Updated on ${date_time}'
         >>> request.response.getStatus()
         302
-        >>> request.response.getHeaders()['Location']
+        >>> request.response.getHeader('Location')
         'http://127.0.0.1'
 
         >>> section.title
@@ -469,7 +469,7 @@ def doctest_SectionEditView():
         ''
         >>> request.response.getStatus()
         302
-        >>> request.response.getHeaders()['Location']
+        >>> request.response.getHeader('Location')
         'http://127.0.0.1'
 
         >>> section.title
@@ -482,7 +482,7 @@ def doctest_SectionEditView():
         ...                 'field.title': u''}
         >>> view = TestSectionEditView(section, request)
         >>> view.update()
-        u'An error occured.'
+        u'An error occurred.'
         >>> request.response.getStatus()
         599
 
@@ -497,7 +497,7 @@ def doctest_SectionEditView():
         >>> view.update()
         >>> request.response.getStatus()
         302
-        >>> request.response.getHeaders()['Location']
+        >>> request.response.getHeader('Location')
         'http://127.0.0.1'
 
     """
@@ -564,7 +564,7 @@ def doctest_SectionInstructorView():
         ['Mr. Smith']
         >>> request.response.getStatus()
         302
-        >>> request.response.getHeaders()['Location']
+        >>> request.response.getHeader('Location')
         'http://127.0.0.1/sections/section'
 
     a Section can have more than one instructor:
@@ -648,7 +648,7 @@ def doctest_SectionLearnerView():
 
         >>> request.response.getStatus()
         302
-        >>> request.response.getHeaders()['Location']
+        >>> request.response.getHeader('Location')
         'http://127.0.0.1/sections/section'
 
     Someone might want to cancel a change.
@@ -663,7 +663,7 @@ def doctest_SectionLearnerView():
         ['John Smith']
         >>> request.response.getStatus()
         302
-        >>> request.response.getHeaders()['Location']
+        >>> request.response.getHeader('Location')
         'http://127.0.0.1/sections/section'
 
     a Section can have more than one learner:
