@@ -19,7 +19,7 @@
 """
 Unit tests for schooltool.rest.
 
-$Id: test_rest.py 4223 2005-07-19 19:38:12Z alga $
+$Id: test_rest.py 5750 2006-02-10 17:36:01Z mg $
 """
 
 from StringIO import StringIO
@@ -43,7 +43,7 @@ def doctest_restSchoolToolSubscriber():
     On an arbitrary object, the subscriber does nothing:
 
         >>> context = object()
-        >>> request = HTTPRequest(StringIO(), StringIO(), {})
+        >>> request = HTTPRequest(StringIO(), {})
         >>> event = BeforeTraverseEvent(context, request)
         >>> restSchoolToolSubscriber(event)
         >>> ISchoolToolRequest.providedBy(request)
