@@ -19,7 +19,7 @@
 """
 Unit tests for schooltool.app.
 
-$Id: test_app.py 4764 2005-08-17 11:05:32Z gintas $
+$Id: test_app.py 5263 2005-10-14 17:36:46Z mg $
 """
 
 import unittest
@@ -727,6 +727,61 @@ def doctest_applicationCalendarPermissionsSubscriber():
     """
 
 
+def doctest_calendar_subscription_shows_timetables():
+    r"""Test for subscribeToPersonTimetables and BoundRelationshipProperty.add.
+
+    Setup
+
+        >>> from schoolbell.relationship.tests import setUpRelationships
+        >>> setup.placelessSetUp()
+        >>> setup.setUpAnnotations()
+        >>> setUpRelationships()
+
+    Subscribe the handler we're testing.
+
+        >>> import zope.event
+        >>> from schooltool.app import subscribeToPersonTimetables
+        >>> zope.event.subscribers.append(subscribeToPersonTimetables)
+
+    Create a few objects.
+
+        >>> from schooltool.app import Person, Group, Resource
+        >>> somebody = Person()
+        >>> person = Person(title='a person')
+        >>> group = Group(title='a group')
+        >>> resource = Resource(title='a resource')
+
+    Add three calendars to the overlay list
+
+        >>> somebody.overlaid_calendars.add(group.calendar)
+        >>> somebody.overlaid_calendars.add(person.calendar)
+        >>> somebody.overlaid_calendars.add(resource.calendar)
+
+    Check that the person's timetable is shown, but the other two timetables
+    are not.
+
+        >>> items = [(ovr_info.calendar.title, ovr_info.show_timetables)
+        ...          for ovr_info in somebody.overlaid_calendars]
+        >>> items.sort()
+        >>> for title, show_tt in items:
+        ...     print '[%s] %s' % (show_tt and '+' or '-', title)
+        [-] a group
+        [+] a person
+        [-] a resource
+
+    The event handler doesn't break if it sees a relationship event for some
+    other relationship type:
+
+        >>> group.members.add(person)
+
+    Teardown
+
+        >>> zope.event.subscribers.remove(subscribeToPersonTimetables)
+        >>> setup.placelessTearDown()
+
+    """
+
+
 def test_suite():
     return unittest.TestSuite([
                 doctest.DocTestSuite(optionflags=doctest.ELLIPSIS),
