@@ -19,7 +19,7 @@
 """
 SchoolTool timetabling views.
 
-$Id: __init__.py 4759 2005-08-17 10:35:24Z gintas $
+$Id: __init__.py 5752 2006-02-11 14:41:40Z ignas $
 """
 
 import datetime
@@ -50,7 +50,7 @@ from schoolbell.calendar.utils import next_month, week_start
 from schoolbell.app.browser.cal import month_names
 from schoolbell.app.cal import CalendarEvent
 
-from schooltool import SchoolToolMessageID as _
+from schooltool import SchoolToolMessage as _
 from schooltool.timetable.interfaces import ITimetable, ITimetableSchema
 from schooltool.timetable.interfaces import ITermContainer, ITerm
 from schooltool.timetable.interfaces import ITimetableSchemaContainer
@@ -144,8 +144,8 @@ class TermEditView(BrowserView, TermEditViewMixin):
         setUpEditWidgets(self, ITermForm)
 
     def title(self):
-        title = _("Change Term: $title")
-        title.mapping = {'title': self.context.title}
+        title = _("Change Term: $title",
+                  mapping={'title': self.context.title})
         return title
 
     def update(self):
@@ -476,15 +476,15 @@ class AdvancedTimetableSchemaAdd(BrowserView, TabindexMixin):
             if 'DELETE_DAY_%d' % n not in self.request:
                 day_id = self.request['day%d' % n].strip()
                 if not day_id:
-                    day_id_msgid = _('Day ${number}')
-                    day_id_msgid.mapping = {'number': len(day_ids) + 1}
+                    day_id_msgid = _('Day ${number}',
+                                     mapping={'number': len(day_ids) + 1})
                     day_id = translate(day_id_msgid, context=self.request)
                 day_ids.append(day_id)
                 day_idxs.append(n)
             n += 1
         if 'ADD_DAY' in self.request or not day_ids:
-            day_id_msgid = _('Day ${number}')
-            day_id_msgid.mapping = {'number': len(day_ids) + 1}
+            day_id_msgid = _('Day ${number}',
+                             mapping={'number': len(day_ids) + 1})
             day_id = translate(day_id_msgid, context=self.request)
             day_ids.append(day_id)
             day_idxs.append(-1)
@@ -516,8 +516,8 @@ class AdvancedTimetableSchemaAdd(BrowserView, TabindexMixin):
             previous_day = periods
 
         if 'ADD_PERIOD' in self.request:
-            period_name_msgid = _('Period ${number}')
-            period_name_msgid.mapping = {'number': len(longest_day) + 1}
+            period_name_msgid = _('Period ${number}',
+                                  mapping = {'number': len(longest_day) + 1})
             period_name = translate(period_name_msgid, context=self.request)
             longest_day.append(period_name)
 
@@ -817,8 +817,8 @@ class TimetableView(BrowserView):
 
     def title(self):
         timetabled = self.context.__parent__.__parent__
-        msg = _("${object}'s timetable")
-        msg.mapping = {'object': timetabled.title}
+        msg = _("${object}'s timetable",
+                mapping={'object': timetabled.title})
         return msg
 
     def rows(self):
@@ -830,8 +830,8 @@ class TimetableSchemaView(TimetableView):
     __used_for__ = ITimetableSchema
 
     def title(self):
-        msg = _("Timetable schema ${schema}")
-        msg.mapping = {'schema': self.context.__name__}
+        msg = _("Timetable schema ${schema}",
+                mapping={'schema': self.context.__name__})
         return msg
 
 
@@ -1434,8 +1434,8 @@ class EmergencyDayView(BrowserView):
             calendar = getSchoolToolApplication().calendar
             dtstart = datetime.datetime.combine(self.date, datetime.time())
             msg = _('School cancelled due to emergency.'
-                    ' Replacement day $replacement.')
-            msg.mapping['replacement'] = str(self.replacement)
+                    ' Replacement day $replacement.',
+                    mapping={'replacement': str(self.replacement)})
             msg = translate(msg, context=self.request)
             calendar.addEvent(
                 CalendarEvent(dtstart, datetime.timedelta(),
@@ -1443,8 +1443,8 @@ class EmergencyDayView(BrowserView):
 
             dtstart = datetime.datetime.combine(self.replacement,
                                                 datetime.time())
-            msg = _('Replacement day for emergency day $emergency.')
-            msg.mapping['emergency'] = str(self.date)
+            msg = _('Replacement day for emergency day $emergency.',
+                    mapping={'emergency': str(self.date)})
             msg = translate(msg, context=self.request)
             calendar.addEvent(
                 CalendarEvent(dtstart, datetime.timedelta(),
