@@ -19,7 +19,7 @@
 """
 Tests for SchoolTool timetable schema wizard.
 
-$Id: test_ttwizard.py 4356 2005-07-25 18:15:39Z alga $
+$Id: test_ttwizard.py 5752 2006-02-11 14:41:40Z ignas $
 """
 
 import unittest
@@ -326,7 +326,7 @@ def doctest_CycleStep():
         >>> view.update()
         True
         >>> session['day_names']
-        ['Monday', 'Tuesday', 'Wednesday', 'Thursday', 'Friday']
+        [u'Monday', u'Tuesday', u'Wednesday', u'Thursday', u'Friday']
 
     """
 
@@ -609,7 +609,7 @@ def doctest_WeeklySlotEntryStep():
         >>> view.getSessionData()['cycle'] = 'weekly'
 
         >>> view.dayNames()
-        ['Monday', 'Tuesday', 'Wednesday', 'Thursday', 'Friday']
+        [u'Monday', u'Tuesday', u'Wednesday', u'Thursday', u'Friday']
 
     At first we get a table with one empty row of input fields:
 
