@@ -19,7 +19,7 @@
 """
 SchoolTool application interfaces
 
-$Id: interfaces.py 4236 2005-07-20 14:30:51Z alga $
+$Id: interfaces.py 5752 2006-02-11 14:41:40Z ignas $
 """
 
 import datetime
@@ -35,7 +35,7 @@ from zope.app.container.constraints import contains, containers
 from schoolbell.app import interfaces as sb
 from schoolbell.calendar.interfaces import Unchanged
 
-from schooltool import SchoolToolMessageID as _
+from schooltool import SchoolToolMessage as _
 
 #
 # Time field used in timetabling interfaces
