@@ -60,6 +60,7 @@ from schooltool.timetable import TimetableSchema, TimetableSchemaDay
 from schooltool.timetable import TimetableSchemaContainer
 from schooltool.rest.interfaces import ITimetableFileFactory
 from schooltool.rest.interfaces import INullTimetable, ICompositeTimetabled
+from schooltool.common import unquote_uri
 
 
 def parseDate(date_str):
@@ -582,7 +583,7 @@ class TimetableFileFactory(object):
         title = activity_node['title']
         resources = []
         for resource in activity_node.query('tt:resource'):
-            path = resource['xlink:href']
+            path = unquote_uri(resource['xlink:href'])
             try:
                 st_app = getSchoolToolApplication()
                 st_url = zapi.absoluteURL(st_app, self.request)
@@ -616,7 +617,7 @@ class TimetablePUT(object):
                 request.response.setStatus(501)
                 return ''
 
-        body = self.request.bodyFile
+        body = self.request.bodyStream
         data = body.read()
         container = self.context.__parent__
         name = self.context.__name__
@@ -712,7 +713,7 @@ class NullTimetablePUT(object):
         name = self.context.name
         factory = queryMultiAdapter((container, self.request),
                                     ITimetableFileFactory)
-        data = self.request.bodyFile.read()
+        data = self.request.bodyStream.read()
         timetable = factory(name, self.request.getHeader('content-type', ''),
                             data)
         notify(ObjectCreatedEvent(timetable))
