@@ -76,6 +76,7 @@ import sys
 import time
 import types
 import getopt
+import doctest
 import unittest
 import traceback
 import linecache
@@ -171,11 +172,11 @@ def get_test_files(cfg):
     """Return a list of test module filenames."""
     matcher = compile_matcher(cfg.pathname_regex)
     allresults = []
-    test_names = []
+    testdir_names = []
     if cfg.functional_tests:
-        test_names.append('ftests')
+        testdir_names.append('ftests')
     if cfg.unit_tests:
-        test_names.append('tests')
+        testdir_names.append('tests')
     baselen = len(cfg.basedir) + 1
     def visit(ignored, dir, files):
         # Ignore files starting with a dot.
@@ -190,9 +191,9 @@ def get_test_files(cfg):
         for idx in remove:
             del files[idx]
         # Skip non-test directories, but look for tests.py and/or ftests.py
-        if os.path.basename(dir) != test_name:
-            if test_name + '.py' in files:
-                path = os.path.join(dir, test_name + '.py')
+        if os.path.basename(dir) != testdir_name:
+            if testdir_name + '.py' in files:
+                path = os.path.join(dir, testdir_name + '.py')
                 if matcher(path[baselen:]):
                     results.append(path)
             return
@@ -209,7 +210,7 @@ def get_test_files(cfg):
     else:
         walker = os.path.walk
 
-    for test_name in test_names:
+    for testdir_name in testdir_names:
         results = []
         for dir in cfg.search_in:
             walker(dir, visit, None)
@@ -222,7 +223,9 @@ def get_test_files(cfg):
 def import_module(filename, cfg, tracer=None):
     """Import and return a module."""
     filename = os.path.splitext(filename)[0]
-    modname = filename[len(cfg.basedir):].replace(os.path.sep, '.')
+    if filename.startswith(cfg.basedir):
+        filename = filename[len(cfg.basedir):]
+    modname = filename.replace(os.path.sep, '.')
     if modname.startswith('.'):
         modname = modname[1:]
     if tracer is not None:
@@ -235,7 +238,36 @@ def import_module(filename, cfg, tracer=None):
     return mod
 
 
-def filter_testsuite(suite, matcher, level=None):
+# Classess passed to isinstance to see whether a test is a DocFileCase.
+# There's doctest.DocFileCase (if you have Python 2.4), and then there might be
+# zope.testing.doctest.DocFileCase.
+if hasattr(doctest, 'DocFileCase'):
+    DocFileCase_classes = (doctest.DocFileCase,)
+else:
+    DocFileCase_classes = ()
+
+
+def name_of_test(test, basedir=None):
+    """Return the name of a test.
+
+    In most cases the name will be "package.module.class.method", however it
+    is different for doctest files, where it will be "subdir/subdir/filename".
+    """
+    if isinstance(test, DocFileCase_classes):
+        # test.id() returns something like "README_txt", while str(test)
+        # returns the pathname
+        doctest_filename = os.path.abspath(str(test))
+        if basedir and doctest_filename.startswith(basedir + '/'):
+            doctest_filename = doctest_filename[len(basedir) + 1:]
+        return doctest_filename
+    else:
+        # test.id() returns something like
+        # "package.module.TestClass.test_method", while str(test)
+        # returns "test_method (package.module.TestClass)".
+        return test.id()
+
+
+def filter_testsuite(suite, matcher, level=None, basedir=None):
     """Return a flattened list of test cases that match the given matcher."""
     if not isinstance(suite, unittest.TestSuite):
         raise TypeError('not a TestSuite', suite)
@@ -244,11 +276,11 @@ def filter_testsuite(suite, matcher, level=None):
         if level is not None and getattr(test, 'level', 0) > level:
             continue
         if isinstance(test, unittest.TestCase):
-            testname = test.id() # package.module.class.method
+            testname = name_of_test(test, basedir)
             if matcher(testname):
                 results.append(test)
         else:
-            filtered = filter_testsuite(test, matcher, level)
+            filtered = filter_testsuite(test, matcher, level, basedir)
             results.extend(filtered)
     return results
 
@@ -315,7 +347,7 @@ def get_test_cases(test_files, cfg, tracer=None):
         if (cfg.level is not None and
             getattr(test_suite, 'level', 0) > cfg.level):
             continue
-        filtered = filter_testsuite(test_suite, matcher, cfg.level)
+        filtered = filter_testsuite(test_suite, matcher, cfg.level, cfg.basedir)
         results.extend(filtered)
     stopTime = time.time()
     timeTaken = float(stopTime - startTime)
@@ -329,22 +361,36 @@ def get_test_cases(test_files, cfg, tracer=None):
 
 def get_test_hooks(test_files, cfg, tracer=None):
     """Return a list of test hooks from a given list of test modules."""
-    results = []
     dirs = Set(map(os.path.dirname, test_files))
     for dir in list(dirs):
         if os.path.basename(dir) == 'ftests':
             dirs.add(os.path.join(os.path.dirname(dir), 'tests'))
     dirs = list(dirs)
     dirs.sort()
+    hook_modules = []
     for dir in dirs:
         filename = os.path.join(dir, 'checks.py')
         if os.path.exists(filename):
             module = import_module(filename, cfg, tracer=tracer)
-            if tracer is not None:
-                hooks = tracer.runfunc(module.test_hooks)
-            else:
-                hooks = module.test_hooks()
-            results.extend(hooks)
+            hook_modules.append(module)
+    # Also look in a a directory 'testsupport' which is a sibling of
+    # cfg.basedir
+    dir = os.path.join(os.path.dirname(cfg.basedir), 'testsupport')
+    filename = os.path.join(dir, 'checks.py')
+    if os.path.exists(filename):
+        sys.path.insert(0, dir)
+        try:
+            module = import_module('checks.py', cfg, tracer=tracer)
+            hook_modules.append(module)
+        finally:
+            del sys.path[0]
+    results = []
+    for module in hook_modules:
+        if tracer is not None:
+            hooks = tracer.runfunc(module.test_hooks)
+        else:
+            hooks = module.test_hooks()
+        results.extend(hooks)
     return results
 
 
@@ -725,11 +771,14 @@ class CustomTestResult(unittest._TextTestResult):
         self.__super_stopTest(test)
 
     def getDescription(self, test):
-        return test.id() # package.module.class.method
+        return name_of_test(test, self.cfg.basedir)
 
     def getShortDescription(self, test):
-        s = test.id() # package.module.class.method
+        s = name_of_test(test, self.cfg.basedir)
         if len(s) > self._maxWidth:
+            # In most cases s is "package.module.class.method".
+            # Try to keep the method name intact, and replace the middle
+            # part of "package.module.class" with an ellipsis.
             namelen = len(s.split('.')[-1])
             left = max(0, (self._maxWidth - namelen) / 2 - 1)
             right = self._maxWidth - left - 3
@@ -866,7 +915,8 @@ def main(argv):
 
     # Defaults
     cfg = Options()
-    cfg.basedir = os.path.join(os.path.dirname(argv[0]), 'src')
+    if not cfg.basedir:
+        cfg.basedir = os.path.join(os.path.dirname(argv[0]), 'src')
     cfg.basedir = os.path.abspath(cfg.basedir)
 
     # Figure out terminal size
@@ -1000,18 +1050,6 @@ def main(argv):
         tracer = trace.Trace(count=True, trace=False,
                     ignoremods=ignoremods, ignoredirs=ignoredirs)
 
-    # Finding and importing
-    test_files = get_test_files(cfg)
-    if cfg.list_tests or cfg.run_tests:
-        test_cases = get_test_cases(test_files, cfg, tracer=tracer)
-    if cfg.list_hooks or cfg.run_tests:
-        test_hooks = get_test_hooks(test_files, cfg, tracer=tracer)
-
-    # Configure the logging module
-    import logging
-    logging.basicConfig()
-    logging.root.setLevel(logging.CRITICAL)
-
     # Configure doctests
     if cfg.first_doctest_failure:
         import doctest
@@ -1025,13 +1063,34 @@ def main(argv):
         except ImportError:
             pass
 
+    # Make sure we can identify doctests before we start the filtering
+    try:
+        import zope.testing.doctest
+        global DocFileCase_classes
+        DocFileCase_classes += (zope.testing.doctest.DocFileCase,)
+    except ImportError:
+        pass
+
+    # Finding and importing
+    test_files = get_test_files(cfg)
+    if cfg.list_tests or cfg.run_tests:
+        test_cases = get_test_cases(test_files, cfg, tracer=tracer)
+    if cfg.list_hooks or cfg.run_tests:
+        test_hooks = get_test_hooks(test_files, cfg, tracer=tracer)
+
+    # Configure the logging module
+    import logging
+    logging.basicConfig()
+    logging.root.setLevel(logging.CRITICAL)
+
     # Running
     success = True
     if cfg.list_files:
         baselen = len(cfg.basedir) + 1
         print "\n".join([fn[baselen:] for fn in test_files])
     if cfg.list_tests:
-        print "\n".join([test.id() for test in test_cases])
+        print "\n".join([name_of_test(test, cfg.basedir)
+                         for test in test_cases])
     if cfg.list_hooks:
         print "\n".join([str(hook) for hook in test_hooks])
     if cfg.run_tests:
